Class: Aws::WellArchitected::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::WellArchitected::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-wellarchitected/client.rb,
sig/client.rbs
Overview
An API client for WellArchitected. To construct a client, you need to configure a :region and :credentials.
client = Aws::WellArchitected::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateAgentContextResponseSuccess, _CreateAgentGoalResponseSuccess, _CreateAgentProfileResponseSuccess, _CreateLensShareResponseSuccess, _CreateLensVersionResponseSuccess, _CreateMilestoneResponseSuccess, _CreateProfileResponseSuccess, _CreateProfileShareResponseSuccess, _CreateReviewTemplateResponseSuccess, _CreateTemplateShareResponseSuccess, _CreateWorkloadResponseSuccess, _CreateWorkloadShareResponseSuccess, _DeleteAgentContextResponseSuccess, _DeleteAgentGoalResponseSuccess, _DeleteAgentProfileResponseSuccess, _ExportLensResponseSuccess, _GetAgentContextResponseSuccess, _GetAgentGoalResponseSuccess, _GetAgentProfileResponseSuccess, _GetAgentRecommendationGenerationResponseSuccess, _GetAgentRecommendationResponseSuccess, _GetAnswerResponseSuccess, _GetConsolidatedReportResponseSuccess, _GetGlobalSettingsResponseSuccess, _GetLensResponseSuccess, _GetLensReviewReportResponseSuccess, _GetLensReviewResponseSuccess, _GetLensVersionDifferenceResponseSuccess, _GetMilestoneResponseSuccess, _GetProfileResponseSuccess, _GetProfileTemplateResponseSuccess, _GetReviewTemplateAnswerResponseSuccess, _GetReviewTemplateLensReviewResponseSuccess, _GetReviewTemplateResponseSuccess, _GetWorkloadResponseSuccess, _ImportLensResponseSuccess, _ListAgentContextsResponseSuccess, _ListAgentGoalsResponseSuccess, _ListAgentProfilesResponseSuccess, _ListAgentRecommendationGenerationsResponseSuccess, _ListAgentRecommendationItemsResponseSuccess, _ListAgentRecommendationsResponseSuccess, _ListAnswersResponseSuccess, _ListCheckDetailsResponseSuccess, _ListCheckSummariesResponseSuccess, _ListLensReviewImprovementsResponseSuccess, _ListLensReviewsResponseSuccess, _ListLensSharesResponseSuccess, _ListLensesResponseSuccess, _ListMilestonesResponseSuccess, _ListNotificationsResponseSuccess, _ListProfileNotificationsResponseSuccess, _ListProfileSharesResponseSuccess, _ListProfilesResponseSuccess, _ListReviewTemplateAnswersResponseSuccess, _ListReviewTemplatesResponseSuccess, _ListShareInvitationsResponseSuccess, _ListTagsForResourceResponseSuccess, _ListTemplateSharesResponseSuccess, _ListWorkloadSharesResponseSuccess, _ListWorkloadsResponseSuccess, _PutAgentRecommendationFeedbackResponseSuccess, _StartAgentRecommendationGenerationResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateAgentContextResponseSuccess, _UpdateAgentGoalResponseSuccess, _UpdateAgentProfileResponseSuccess, _UpdateAgentRecommendationStatusResponseSuccess, _UpdateAnswerResponseSuccess, _UpdateLensReviewResponseSuccess, _UpdateProfileResponseSuccess, _UpdateReviewTemplateAnswerResponseSuccess, _UpdateReviewTemplateLensReviewResponseSuccess, _UpdateReviewTemplateResponseSuccess, _UpdateShareInvitationResponseSuccess, _UpdateWorkloadResponseSuccess, _UpdateWorkloadShareResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_lenses(params = {}) ⇒ Struct
Associate a lens to a workload.
-
#associate_profiles(params = {}) ⇒ Struct
Associate a profile with a workload.
-
#create_agent_context(params = {}) ⇒ Types::CreateAgentContextResponse
Creates a context associated with an optimization profile.
-
#create_agent_goal(params = {}) ⇒ Types::CreateAgentGoalResponse
Creates an optimization goal associated with a profile.
-
#create_agent_profile(params = {}) ⇒ Types::CreateAgentProfileResponse
Creates an optimization profile that defines the scope and configuration for generating recommendations.
-
#create_lens_share(params = {}) ⇒ Types::CreateLensShareOutput
Create a lens share.
-
#create_lens_version(params = {}) ⇒ Types::CreateLensVersionOutput
Create a new lens version.
-
#create_milestone(params = {}) ⇒ Types::CreateMilestoneOutput
Create a milestone for an existing workload.
-
#create_profile(params = {}) ⇒ Types::CreateProfileOutput
Create a profile.
-
#create_profile_share(params = {}) ⇒ Types::CreateProfileShareOutput
Create a profile share.
-
#create_review_template(params = {}) ⇒ Types::CreateReviewTemplateOutput
Create a review template.
-
#create_template_share(params = {}) ⇒ Types::CreateTemplateShareOutput
Create a review template share.
-
#create_workload(params = {}) ⇒ Types::CreateWorkloadOutput
Create a new workload.
-
#create_workload_share(params = {}) ⇒ Types::CreateWorkloadShareOutput
Create a workload share.
-
#delete_agent_context(params = {}) ⇒ Struct
Deletes a context associated with a profile.
-
#delete_agent_goal(params = {}) ⇒ Struct
Deletes an optimization goal from a profile.
-
#delete_agent_profile(params = {}) ⇒ Struct
Deletes an optimization profile and its associated configuration.
-
#delete_lens(params = {}) ⇒ Struct
Delete an existing lens.
-
#delete_lens_share(params = {}) ⇒ Struct
Delete a lens share.
-
#delete_profile(params = {}) ⇒ Struct
Delete a profile.
-
#delete_profile_share(params = {}) ⇒ Struct
Delete a profile share.
-
#delete_review_template(params = {}) ⇒ Struct
Delete a review template.
-
#delete_template_share(params = {}) ⇒ Struct
Delete a review template share.
-
#delete_workload(params = {}) ⇒ Struct
Delete an existing workload.
-
#delete_workload_share(params = {}) ⇒ Struct
Delete a workload share.
-
#disassociate_lenses(params = {}) ⇒ Struct
Disassociate a lens from a workload.
-
#disassociate_profiles(params = {}) ⇒ Struct
Disassociate a profile from a workload.
-
#export_lens(params = {}) ⇒ Types::ExportLensOutput
Export an existing lens.
-
#get_agent_context(params = {}) ⇒ Types::GetAgentContextResponse
Retrieves detailed information about a specific context associated with a profile.
-
#get_agent_goal(params = {}) ⇒ Types::GetAgentGoalResponse
Retrieves detailed information about a specific optimization goal.
-
#get_agent_profile(params = {}) ⇒ Types::GetAgentProfileResponse
Retrieves detailed information about an optimization profile, including its configuration and metadata.
-
#get_agent_recommendation(params = {}) ⇒ Types::GetAgentRecommendationResponse
Retrieves detailed information about a specific optimization recommendation, including its impact analysis, content, and implementation guidance.
-
#get_agent_recommendation_generation(params = {}) ⇒ Types::GetAgentRecommendationGenerationResponse
Retrieves information about a recommendation generation process, including its status, progress, and results.
-
#get_answer(params = {}) ⇒ Types::GetAnswerOutput
Get the answer to a specific question in a workload review.
-
#get_consolidated_report(params = {}) ⇒ Types::GetConsolidatedReportOutput
Get a consolidated report of your workloads.
-
#get_global_settings(params = {}) ⇒ Types::GetGlobalSettingsOutput
Global settings for all workloads.
-
#get_lens(params = {}) ⇒ Types::GetLensOutput
Get an existing lens.
-
#get_lens_review(params = {}) ⇒ Types::GetLensReviewOutput
Get lens review.
-
#get_lens_review_report(params = {}) ⇒ Types::GetLensReviewReportOutput
Get lens review report.
-
#get_lens_version_difference(params = {}) ⇒ Types::GetLensVersionDifferenceOutput
Get lens version differences.
-
#get_milestone(params = {}) ⇒ Types::GetMilestoneOutput
Get a milestone for an existing workload.
-
#get_profile(params = {}) ⇒ Types::GetProfileOutput
Get profile information.
-
#get_profile_template(params = {}) ⇒ Types::GetProfileTemplateOutput
Get profile template.
-
#get_review_template(params = {}) ⇒ Types::GetReviewTemplateOutput
Get review template.
-
#get_review_template_answer(params = {}) ⇒ Types::GetReviewTemplateAnswerOutput
Get review template answer.
-
#get_review_template_lens_review(params = {}) ⇒ Types::GetReviewTemplateLensReviewOutput
Get a lens review associated with a review template.
-
#get_workload(params = {}) ⇒ Types::GetWorkloadOutput
Get an existing workload.
-
#import_lens(params = {}) ⇒ Types::ImportLensOutput
Import a new custom lens or update an existing custom lens.
-
#list_agent_contexts(params = {}) ⇒ Types::ListAgentContextsResponse
Lists contexts associated with a profile.
-
#list_agent_goals(params = {}) ⇒ Types::ListAgentGoalsResponse
Lists optimization goals associated with a specified profile.
-
#list_agent_profiles(params = {}) ⇒ Types::ListAgentProfilesResponse
Lists optimization profiles in your account.
-
#list_agent_recommendation_generations(params = {}) ⇒ Types::ListAgentRecommendationGenerationsResponse
Lists recommendation generation processes for a specified profile.
-
#list_agent_recommendation_items(params = {}) ⇒ Types::ListAgentRecommendationItemsResponse
Lists recommendation items for a specific recommendation.
-
#list_agent_recommendations(params = {}) ⇒ Types::ListAgentRecommendationsResponse
Lists active optimization recommendations for a specified profile with optional filtering by state.
-
#list_answers(params = {}) ⇒ Types::ListAnswersOutput
List of answers for a particular workload and lens.
-
#list_check_details(params = {}) ⇒ Types::ListCheckDetailsOutput
List of Trusted Advisor check details by account related to the workload.
-
#list_check_summaries(params = {}) ⇒ Types::ListCheckSummariesOutput
List of Trusted Advisor checks summarized for all accounts related to the workload.
-
#list_lens_review_improvements(params = {}) ⇒ Types::ListLensReviewImprovementsOutput
List the improvements of a particular lens review.
-
#list_lens_reviews(params = {}) ⇒ Types::ListLensReviewsOutput
List lens reviews for a particular workload.
-
#list_lens_shares(params = {}) ⇒ Types::ListLensSharesOutput
List the lens shares associated with the lens.
-
#list_lenses(params = {}) ⇒ Types::ListLensesOutput
List the available lenses.
-
#list_milestones(params = {}) ⇒ Types::ListMilestonesOutput
List all milestones for an existing workload.
-
#list_notifications(params = {}) ⇒ Types::ListNotificationsOutput
List lens notifications.
-
#list_profile_notifications(params = {}) ⇒ Types::ListProfileNotificationsOutput
List profile notifications.
-
#list_profile_shares(params = {}) ⇒ Types::ListProfileSharesOutput
List profile shares.
-
#list_profiles(params = {}) ⇒ Types::ListProfilesOutput
List profiles.
-
#list_review_template_answers(params = {}) ⇒ Types::ListReviewTemplateAnswersOutput
List the answers of a review template.
-
#list_review_templates(params = {}) ⇒ Types::ListReviewTemplatesOutput
List review templates.
-
#list_share_invitations(params = {}) ⇒ Types::ListShareInvitationsOutput
List the share invitations.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
List the tags for a resource.
-
#list_template_shares(params = {}) ⇒ Types::ListTemplateSharesOutput
List review template shares.
-
#list_workload_shares(params = {}) ⇒ Types::ListWorkloadSharesOutput
List the workload shares associated with the workload.
-
#list_workloads(params = {}) ⇒ Types::ListWorkloadsOutput
Paginated list of workloads.
-
#put_agent_recommendation_feedback(params = {}) ⇒ Struct
Submits user feedback on a recommendation to help improve future optimization suggestions and track implementation outcomes.
-
#start_agent_recommendation_generation(params = {}) ⇒ Types::StartAgentRecommendationGenerationResponse
Initiates a new recommendation generation process for the specified optimization profile.
-
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Deletes specified tags from a resource.
-
#update_agent_context(params = {}) ⇒ Types::UpdateAgentContextResponse
Updates an existing context associated with a profile.
-
#update_agent_goal(params = {}) ⇒ Types::UpdateAgentGoalResponse
Updates the pillars and title of an existing goal associated with a profile.
-
#update_agent_profile(params = {}) ⇒ Types::UpdateAgentProfileResponse
Updates an existing optimization profile's configuration, including its pillars, execution role, and aggregation settings.
-
#update_agent_recommendation_status(params = {}) ⇒ Struct
Updates the status of a recommendation to track its progress through the implementation lifecycle.
-
#update_answer(params = {}) ⇒ Types::UpdateAnswerOutput
Update the answer to a specific question in a workload review.
-
#update_global_settings(params = {}) ⇒ Struct
Update whether the Amazon Web Services account is opted into organization sharing and discovery integration features.
-
#update_integration(params = {}) ⇒ Struct
Update integration features.
-
#update_lens_review(params = {}) ⇒ Types::UpdateLensReviewOutput
Update lens review for a particular workload.
-
#update_profile(params = {}) ⇒ Types::UpdateProfileOutput
Update a profile.
-
#update_review_template(params = {}) ⇒ Types::UpdateReviewTemplateOutput
Update a review template.
-
#update_review_template_answer(params = {}) ⇒ Types::UpdateReviewTemplateAnswerOutput
Update a review template answer.
-
#update_review_template_lens_review(params = {}) ⇒ Types::UpdateReviewTemplateLensReviewOutput
Update a lens review associated with a review template.
-
#update_share_invitation(params = {}) ⇒ Types::UpdateShareInvitationOutput
Update a workload or custom lens share invitation.
-
#update_workload(params = {}) ⇒ Types::UpdateWorkloadOutput
Update an existing workload.
-
#update_workload_share(params = {}) ⇒ Types::UpdateWorkloadShareOutput
Update a workload share.
-
#upgrade_lens_review(params = {}) ⇒ Struct
Upgrade lens review for a particular workload.
-
#upgrade_profile_version(params = {}) ⇒ Struct
Upgrade a profile.
-
#upgrade_review_template_lens_review(params = {}) ⇒ Struct
Upgrade the lens review of a review template.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-wellarchitected/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6789 6790 6791 |
# File 'lib/aws-sdk-wellarchitected/client.rb', line 6789 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6792 6793 6794 |
# File 'lib/aws-sdk-wellarchitected/client.rb', line 6792 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14 def self.new: ( |
Instance Method Details
#associate_lenses(params = {}) ⇒ Struct
Associate a lens to a workload.
Up to 10 lenses can be associated with a workload in a single API operation. A maximum of 20 lenses can be associated with a workload.
By accessing and/or applying custom lenses created by another Amazon Web Services user or account, you acknowledge that custom lenses created by other users and shared with you are Third Party Content as defined in the Amazon Web Services Customer Agreement.
82 |
# File 'sig/client.rbs', line 82 def associate_lenses: ( |
#associate_profiles(params = {}) ⇒ Struct
Associate a profile with a workload.
89 |
# File 'sig/client.rbs', line 89 def associate_profiles: ( |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6762 6763 6764 6765 6766 6767 6768 6769 6770 6771 6772 6773 6774 6775 6776 6777 6778 |
# File 'lib/aws-sdk-wellarchitected/client.rb', line 6762 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::WellArchitected') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-wellarchitected' context[:gem_version] = '1.75.0' Seahorse::Client::Request.new(handlers, context) end |
#create_agent_context(params = {}) ⇒ Types::CreateAgentContextResponse
Creates a context associated with an optimization profile. Contexts provide application and environment information used during recommendation generation.
99 |
# File 'sig/client.rbs', line 99 def create_agent_context: ( |
#create_agent_goal(params = {}) ⇒ Types::CreateAgentGoalResponse
Creates an optimization goal associated with a profile. Goals define specific targets and objectives for the optimization process.
113 |
# File 'sig/client.rbs', line 113 def create_agent_goal: ( |
#create_agent_profile(params = {}) ⇒ Types::CreateAgentProfileResponse
Creates an optimization profile that defines the scope and configuration for generating recommendations. A profile specifies the execution role, target pillars, and aggregation settings for analyzing your Amazon Web Services resources.
143 |
# File 'sig/client.rbs', line 143 def create_agent_profile: ( |
#create_lens_share(params = {}) ⇒ Types::CreateLensShareOutput
Create a lens share.
The owner of a lens can share it with other Amazon Web Services accounts, users, an organization, and organizational units (OUs) in the same Amazon Web Services Region. Lenses provided by Amazon Web Services (Amazon Web Services Official Content) cannot be shared.
Shared access to a lens is not removed until the lens invitation is deleted.
If you share a lens with an organization or OU, all accounts in the organization or OU are granted access to the lens.
For more information, see Sharing a custom lens in the Well-Architected Tool User Guide.
By sharing your custom lenses with other Amazon Web Services accounts, you acknowledge that Amazon Web Services will make your custom lenses available to those other accounts. Those other accounts may continue to access and use your shared custom lenses even if you delete the custom lenses from your own Amazon Web Services account or terminate your Amazon Web Services account.
173 |
# File 'sig/client.rbs', line 173 def create_lens_share: ( |
#create_lens_version(params = {}) ⇒ Types::CreateLensVersionOutput
Create a new lens version.
A lens can have up to 100 versions.
Use this operation to publish a new lens version after you have
imported a lens. The LensAlias is used to identify the lens to be
published. The owner of a lens can share the lens with other Amazon
Web Services accounts and users in the same Amazon Web Services
Region. Only the owner of a lens can delete it.
186 |
# File 'sig/client.rbs', line 186 def create_lens_version: ( |
#create_milestone(params = {}) ⇒ Types::CreateMilestoneOutput
Create a milestone for an existing workload.
200 |
# File 'sig/client.rbs', line 200 def create_milestone: ( |
#create_profile(params = {}) ⇒ Types::CreateProfileOutput
Create a profile.
213 |
# File 'sig/client.rbs', line 213 def create_profile: ( |
#create_profile_share(params = {}) ⇒ Types::CreateProfileShareOutput
Create a profile share.
233 |
# File 'sig/client.rbs', line 233 def create_profile_share: ( |
#create_review_template(params = {}) ⇒ Types::CreateReviewTemplateOutput
Create a review template.
Do not include or gather personal identifiable information (PII) of end users or other identifiable individuals in or via your review templates. If your review template or those shared with you and used in your account do include or collect PII you are responsible for: ensuring that the included PII is processed in accordance with applicable law, providing adequate privacy notices, and obtaining necessary consents for processing such data.
245 |
# File 'sig/client.rbs', line 245 def create_review_template: ( |
#create_template_share(params = {}) ⇒ Types::CreateTemplateShareOutput
Create a review template share.
The owner of a review template can share it with other Amazon Web Services accounts, users, an organization, and organizational units (OUs) in the same Amazon Web Services Region.
Shared access to a review template is not removed until the review template share invitation is deleted.
If you share a review template with an organization or OU, all accounts in the organization or OU are granted access to the review template.
By sharing your review template with other Amazon Web Services accounts, you acknowledge that Amazon Web Services will make your review template available to those other accounts.
261 |
# File 'sig/client.rbs', line 261 def create_template_share: ( |
#create_workload(params = {}) ⇒ Types::CreateWorkloadOutput
Create a new workload.
The owner of a workload can share the workload with other Amazon Web Services accounts, users, an organization, and organizational units (OUs) in the same Amazon Web Services Region. Only the owner of a workload can delete it.
For more information, see Defining a Workload in the Well-Architected Tool User Guide.
Either AwsRegions, NonAwsRegions, or both must be specified when
creating a workload.
You also must specify ReviewOwner, even though the parameter is
listed as not being required in the following section.
When creating a workload using a review template, you must have the following IAM permissions:
-
wellarchitected:GetReviewTemplate -
wellarchitected:GetReviewTemplateAnswer -
wellarchitected:ListReviewTemplateAnswers -
wellarchitected:GetReviewTemplateLensReview
274 |
# File 'sig/client.rbs', line 274 def create_workload: ( |
#create_workload_share(params = {}) ⇒ Types::CreateWorkloadShareOutput
Create a workload share.
The owner of a workload can share it with other Amazon Web Services accounts and users in the same Amazon Web Services Region. Shared access to a workload is not removed until the workload invitation is deleted.
If you share a workload with an organization or OU, all accounts in the organization or OU are granted access to the workload.
For more information, see Sharing a workload in the Well-Architected Tool User Guide.
311 |
# File 'sig/client.rbs', line 311 def create_workload_share: ( |
#delete_agent_context(params = {}) ⇒ Struct
Deletes a context associated with a profile.
323 |
# File 'sig/client.rbs', line 323 def delete_agent_context: ( |
#delete_agent_goal(params = {}) ⇒ Struct
Deletes an optimization goal from a profile.
333 |
# File 'sig/client.rbs', line 333 def delete_agent_goal: ( |
#delete_agent_profile(params = {}) ⇒ Struct
Deletes an optimization profile and its associated configuration. This action cannot be undone.
343 |
# File 'sig/client.rbs', line 343 def delete_agent_profile: ( |
#delete_lens(params = {}) ⇒ Struct
Delete an existing lens.
Only the owner of a lens can delete it. After the lens is deleted, Amazon Web Services accounts and users that you shared the lens with can continue to use it, but they will no longer be able to apply it to new workloads.
By sharing your custom lenses with other Amazon Web Services accounts, you acknowledge that Amazon Web Services will make your custom lenses available to those other accounts. Those other accounts may continue to access and use your shared custom lenses even if you delete the custom lenses from your own Amazon Web Services account or terminate your Amazon Web Services account.
349 |
# File 'sig/client.rbs', line 349 def delete_lens: ( |
#delete_lens_share(params = {}) ⇒ Struct
Delete a lens share.
After the lens share is deleted, Amazon Web Services accounts, users, organizations, and organizational units (OUs) that you shared the lens with can continue to use it, but they will no longer be able to apply it to new workloads.
By sharing your custom lenses with other Amazon Web Services accounts, you acknowledge that Amazon Web Services will make your custom lenses available to those other accounts. Those other accounts may continue to access and use your shared custom lenses even if you delete the custom lenses from your own Amazon Web Services account or terminate your Amazon Web Services account.
357 |
# File 'sig/client.rbs', line 357 def delete_lens_share: ( |
#delete_profile(params = {}) ⇒ Struct
Delete a profile.
By sharing your profile with other Amazon Web Services accounts, you acknowledge that Amazon Web Services will make your profile available to those other accounts. Those other accounts may continue to access and use your shared profile even if you delete the profile from your own Amazon Web Services account or terminate your Amazon Web Services account.
365 |
# File 'sig/client.rbs', line 365 def delete_profile: ( |
#delete_profile_share(params = {}) ⇒ Struct
Delete a profile share.
372 |
# File 'sig/client.rbs', line 372 def delete_profile_share: ( |
#delete_review_template(params = {}) ⇒ Struct
Delete a review template.
Only the owner of a review template can delete it.
After the review template is deleted, Amazon Web Services accounts, users, organizations, and organizational units (OUs) that you shared the review template with will no longer be able to apply it to new workloads.
380 |
# File 'sig/client.rbs', line 380 def delete_review_template: ( |
#delete_template_share(params = {}) ⇒ Struct
Delete a review template share.
After the review template share is deleted, Amazon Web Services accounts, users, organizations, and organizational units (OUs) that you shared the review template with will no longer be able to apply it to new workloads.
387 |
# File 'sig/client.rbs', line 387 def delete_template_share: ( |
#delete_workload(params = {}) ⇒ Struct
Delete an existing workload.
395 |
# File 'sig/client.rbs', line 395 def delete_workload: ( |
#delete_workload_share(params = {}) ⇒ Struct
Delete a workload share.
402 |
# File 'sig/client.rbs', line 402 def delete_workload_share: ( |
#disassociate_lenses(params = {}) ⇒ Struct
Disassociate a lens from a workload.
Up to 10 lenses can be disassociated from a workload in a single API operation.
wellarchitected) cannot be removed from a workload.
410 |
# File 'sig/client.rbs', line 410 def disassociate_lenses: ( |
#disassociate_profiles(params = {}) ⇒ Struct
Disassociate a profile from a workload.
417 |
# File 'sig/client.rbs', line 417 def disassociate_profiles: ( |
#export_lens(params = {}) ⇒ Types::ExportLensOutput
Export an existing lens.
Only the owner of a lens can export it. Lenses provided by Amazon Web Services (Amazon Web Services Official Content) cannot be exported.
Lenses are defined in JSON. For more information, see JSON format specification in the Well-Architected Tool User Guide.
Do not include or gather personal identifiable information (PII) of end users or other identifiable individuals in or via your custom lenses. If your custom lens or those shared with you and used in your account do include or collect PII you are responsible for: ensuring that the included PII is processed in accordance with applicable law, providing adequate privacy notices, and obtaining necessary consents for processing such data.
428 |
# File 'sig/client.rbs', line 428 def export_lens: ( |
#get_agent_context(params = {}) ⇒ Types::GetAgentContextResponse
Retrieves detailed information about a specific context associated with a profile.
438 |
# File 'sig/client.rbs', line 438 def get_agent_context: ( |
#get_agent_goal(params = {}) ⇒ Types::GetAgentGoalResponse
Retrieves detailed information about a specific optimization goal.
449 |
# File 'sig/client.rbs', line 449 def get_agent_goal: ( |
#get_agent_profile(params = {}) ⇒ Types::GetAgentProfileResponse
Retrieves detailed information about an optimization profile, including its configuration and metadata.
476 |
# File 'sig/client.rbs', line 476 def get_agent_profile: ( |
#get_agent_recommendation(params = {}) ⇒ Types::GetAgentRecommendationResponse
Retrieves detailed information about a specific optimization recommendation, including its impact analysis, content, and implementation guidance.
517 |
# File 'sig/client.rbs', line 517 def get_agent_recommendation: ( |
#get_agent_recommendation_generation(params = {}) ⇒ Types::GetAgentRecommendationGenerationResponse
Retrieves information about a recommendation generation process, including its status, progress, and results. Recommendation generation is asynchronous: poll this operation until status reaches a terminal value of COMPLETED (results are ready) or ERROR (see errorDetails). Intermediate values are QUEUED and IN_PROGRESS.
542 |
# File 'sig/client.rbs', line 542 def get_agent_recommendation_generation: ( |
#get_answer(params = {}) ⇒ Types::GetAnswerOutput
Get the answer to a specific question in a workload review.
557 |
# File 'sig/client.rbs', line 557 def get_answer: ( |
#get_consolidated_report(params = {}) ⇒ Types::GetConsolidatedReportOutput
Get a consolidated report of your workloads.
You can optionally choose to include workloads that have been shared with you.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
572 |
# File 'sig/client.rbs', line 572 def get_consolidated_report: ( |
#get_global_settings(params = {}) ⇒ Types::GetGlobalSettingsOutput
Global settings for all workloads.
587 588 |
# File 'sig/client.rbs', line 587 def get_global_settings: () -> _GetGlobalSettingsResponseSuccess | (?Hash[Symbol, untyped] params, ?Hash[Symbol, untyped] ) -> _GetGlobalSettingsResponseSuccess |
#get_lens(params = {}) ⇒ Types::GetLensOutput
Get an existing lens.
595 |
# File 'sig/client.rbs', line 595 def get_lens: ( |
#get_lens_review(params = {}) ⇒ Types::GetLensReviewOutput
Get lens review.
608 |
# File 'sig/client.rbs', line 608 def get_lens_review: ( |
#get_lens_review_report(params = {}) ⇒ Types::GetLensReviewReportOutput
Get lens review report.
622 |
# File 'sig/client.rbs', line 622 def get_lens_review_report: ( |
#get_lens_version_difference(params = {}) ⇒ Types::GetLensVersionDifferenceOutput
Get lens version differences.
639 |
# File 'sig/client.rbs', line 639 def get_lens_version_difference: ( |
#get_milestone(params = {}) ⇒ Types::GetMilestoneOutput
Get a milestone for an existing workload.
652 |
# File 'sig/client.rbs', line 652 def get_milestone: ( |
#get_profile(params = {}) ⇒ Types::GetProfileOutput
Get profile information.
663 |
# File 'sig/client.rbs', line 663 def get_profile: ( |
#get_profile_template(params = {}) ⇒ Types::GetProfileTemplateOutput
Get profile template.
674 |
# File 'sig/client.rbs', line 674 def get_profile_template: ( |
#get_review_template(params = {}) ⇒ Types::GetReviewTemplateOutput
Get review template.
683 |
# File 'sig/client.rbs', line 683 def get_review_template: ( |
#get_review_template_answer(params = {}) ⇒ Types::GetReviewTemplateAnswerOutput
Get review template answer.
695 |
# File 'sig/client.rbs', line 695 def get_review_template_answer: ( |
#get_review_template_lens_review(params = {}) ⇒ Types::GetReviewTemplateLensReviewOutput
Get a lens review associated with a review template.
708 |
# File 'sig/client.rbs', line 708 def get_review_template_lens_review: ( |
#get_workload(params = {}) ⇒ Types::GetWorkloadOutput
Get an existing workload.
719 |
# File 'sig/client.rbs', line 719 def get_workload: ( |
#import_lens(params = {}) ⇒ Types::ImportLensOutput
Import a new custom lens or update an existing custom lens.
To update an existing custom lens, specify its ARN as the LensAlias.
If no ARN is specified, a new custom lens is created.
The new or updated lens will have a status of DRAFT. The lens cannot
be applied to workloads or shared with other Amazon Web Services
accounts until it's published with CreateLensVersion.
Lenses are defined in JSON. For more information, see JSON format specification in the Well-Architected Tool User Guide.
A custom lens cannot exceed 500 KB in size.
Do not include or gather personal identifiable information (PII) of end users or other identifiable individuals in or via your custom lenses. If your custom lens or those shared with you and used in your account do include or collect PII you are responsible for: ensuring that the included PII is processed in accordance with applicable law, providing adequate privacy notices, and obtaining necessary consents for processing such data.
730 |
# File 'sig/client.rbs', line 730 def import_lens: ( |
#list_agent_contexts(params = {}) ⇒ Types::ListAgentContextsResponse
Lists contexts associated with a profile.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
744 |
# File 'sig/client.rbs', line 744 def list_agent_contexts: ( |
#list_agent_goals(params = {}) ⇒ Types::ListAgentGoalsResponse
Lists optimization goals associated with a specified profile. Goals define specific targets and objectives for the optimization process.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
757 |
# File 'sig/client.rbs', line 757 def list_agent_goals: ( |
#list_agent_profiles(params = {}) ⇒ Types::ListAgentProfilesResponse
Lists optimization profiles in your account. Profiles define the scope and configuration for generating optimization recommendations.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
770 |
# File 'sig/client.rbs', line 770 def list_agent_profiles: ( |
#list_agent_recommendation_generations(params = {}) ⇒ Types::ListAgentRecommendationGenerationsResponse
Lists recommendation generation processes for a specified profile.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
782 |
# File 'sig/client.rbs', line 782 def list_agent_recommendation_generations: ( |
#list_agent_recommendation_items(params = {}) ⇒ Types::ListAgentRecommendationItemsResponse
Lists recommendation items for a specific recommendation. Recommendation items provide detailed information about individual optimization opportunities.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
796 |
# File 'sig/client.rbs', line 796 def list_agent_recommendation_items: ( |
#list_agent_recommendations(params = {}) ⇒ Types::ListAgentRecommendationsResponse
Lists active optimization recommendations for a specified profile with optional filtering by state.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
810 |
# File 'sig/client.rbs', line 810 def list_agent_recommendations: ( |
#list_answers(params = {}) ⇒ Types::ListAnswersOutput
List of answers for a particular workload and lens.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
829 |
# File 'sig/client.rbs', line 829 def list_answers: ( |
#list_check_details(params = {}) ⇒ Types::ListCheckDetailsOutput
List of Trusted Advisor check details by account related to the workload.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
846 |
# File 'sig/client.rbs', line 846 def list_check_details: ( |
#list_check_summaries(params = {}) ⇒ Types::ListCheckSummariesOutput
List of Trusted Advisor checks summarized for all accounts related to the workload.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
863 |
# File 'sig/client.rbs', line 863 def list_check_summaries: ( |
#list_lens_review_improvements(params = {}) ⇒ Types::ListLensReviewImprovementsOutput
List the improvements of a particular lens review.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
884 |
# File 'sig/client.rbs', line 884 def list_lens_review_improvements: ( |
#list_lens_reviews(params = {}) ⇒ Types::ListLensReviewsOutput
List lens reviews for a particular workload.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
903 |
# File 'sig/client.rbs', line 903 def list_lens_reviews: ( |
#list_lens_shares(params = {}) ⇒ Types::ListLensSharesOutput
List the lens shares associated with the lens.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
917 |
# File 'sig/client.rbs', line 917 def list_lens_shares: ( |
#list_lenses(params = {}) ⇒ Types::ListLensesOutput
List the available lenses.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
932 |
# File 'sig/client.rbs', line 932 def list_lenses: ( |
#list_milestones(params = {}) ⇒ Types::ListMilestonesOutput
List all milestones for an existing workload.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
948 |
# File 'sig/client.rbs', line 948 def list_milestones: ( |
#list_notifications(params = {}) ⇒ Types::ListNotificationsOutput
List lens notifications.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
961 |
# File 'sig/client.rbs', line 961 def list_notifications: ( |
#list_profile_notifications(params = {}) ⇒ Types::ListProfileNotificationsOutput
List profile notifications.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
975 |
# File 'sig/client.rbs', line 975 def list_profile_notifications: ( |
#list_profile_shares(params = {}) ⇒ Types::ListProfileSharesOutput
List profile shares.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
988 |
# File 'sig/client.rbs', line 988 def list_profile_shares: ( |
#list_profiles(params = {}) ⇒ Types::ListProfilesOutput
List profiles.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1003 |
# File 'sig/client.rbs', line 1003 def list_profiles: ( |
#list_review_template_answers(params = {}) ⇒ Types::ListReviewTemplateAnswersOutput
List the answers of a review template.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1019 |
# File 'sig/client.rbs', line 1019 def list_review_template_answers: ( |
#list_review_templates(params = {}) ⇒ Types::ListReviewTemplatesOutput
List review templates.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1034 |
# File 'sig/client.rbs', line 1034 def list_review_templates: ( |
#list_share_invitations(params = {}) ⇒ Types::ListShareInvitationsOutput
List the share invitations.
WorkloadNamePrefix, LensNamePrefix, ProfileNamePrefix, and
TemplateNamePrefix are mutually exclusive. Use the parameter that
matches your ShareResourceType.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1046 |
# File 'sig/client.rbs', line 1046 def list_share_invitations: ( |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
List the tags for a resource.
1062 |
# File 'sig/client.rbs', line 1062 def list_tags_for_resource: ( |
#list_template_shares(params = {}) ⇒ Types::ListTemplateSharesOutput
List review template shares.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1074 |
# File 'sig/client.rbs', line 1074 def list_template_shares: ( |
#list_workload_shares(params = {}) ⇒ Types::ListWorkloadSharesOutput
List the workload shares associated with the workload.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1090 |
# File 'sig/client.rbs', line 1090 def list_workload_shares: ( |
#list_workloads(params = {}) ⇒ Types::ListWorkloadsOutput
Paginated list of workloads.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1105 |
# File 'sig/client.rbs', line 1105 def list_workloads: ( |
#put_agent_recommendation_feedback(params = {}) ⇒ Struct
Submits user feedback on a recommendation to help improve future optimization suggestions and track implementation outcomes.
1116 |
# File 'sig/client.rbs', line 1116 def put_agent_recommendation_feedback: ( |
#start_agent_recommendation_generation(params = {}) ⇒ Types::StartAgentRecommendationGenerationResponse
Initiates a new recommendation generation process for the specified optimization profile. This asynchronous operation analyzes your Amazon Web Services resources and generates optimization recommendations based on the configured pillars and scope. Use GetAgentRecommendationGeneration to check status.
1137 |
# File 'sig/client.rbs', line 1137 def start_agent_recommendation_generation: ( |
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to the specified resource.
1160 |
# File 'sig/client.rbs', line 1160 def tag_resource: ( |
#untag_resource(params = {}) ⇒ Struct
Deletes specified tags from a resource.
To specify multiple tags, use separate tagKeys parameters, for example:
DELETE /tags/WorkloadArn?tagKeys=key1&tagKeys=key2
1170 |
# File 'sig/client.rbs', line 1170 def untag_resource: ( |
#update_agent_context(params = {}) ⇒ Types::UpdateAgentContextResponse
Updates an existing context associated with a profile.
1180 |
# File 'sig/client.rbs', line 1180 def update_agent_context: ( |
#update_agent_goal(params = {}) ⇒ Types::UpdateAgentGoalResponse
Updates the pillars and title of an existing goal associated with a profile.
1194 |
# File 'sig/client.rbs', line 1194 def update_agent_goal: ( |
#update_agent_profile(params = {}) ⇒ Types::UpdateAgentProfileResponse
Updates an existing optimization profile's configuration, including its pillars, execution role, and aggregation settings.
1225 |
# File 'sig/client.rbs', line 1225 def update_agent_profile: ( |
#update_agent_recommendation_status(params = {}) ⇒ Struct
Updates the status of a recommendation to track its progress through the implementation lifecycle.
1248 |
# File 'sig/client.rbs', line 1248 def update_agent_recommendation_status: ( |
#update_answer(params = {}) ⇒ Types::UpdateAnswerOutput
Update the answer to a specific question in a workload review.
1263 |
# File 'sig/client.rbs', line 1263 def update_answer: ( |
#update_global_settings(params = {}) ⇒ Struct
Update whether the Amazon Web Services account is opted into organization sharing and discovery integration features.
1280 |
# File 'sig/client.rbs', line 1280 def update_global_settings: ( |
#update_integration(params = {}) ⇒ Struct
Update integration features.
1293 |
# File 'sig/client.rbs', line 1293 def update_integration: ( |
#update_lens_review(params = {}) ⇒ Types::UpdateLensReviewOutput
Update lens review for a particular workload.
1306 |
# File 'sig/client.rbs', line 1306 def update_lens_review: ( |
#update_profile(params = {}) ⇒ Types::UpdateProfileOutput
Update a profile.
1327 |
# File 'sig/client.rbs', line 1327 def update_profile: ( |
#update_review_template(params = {}) ⇒ Types::UpdateReviewTemplateOutput
Update a review template.
1344 |
# File 'sig/client.rbs', line 1344 def update_review_template: ( |
#update_review_template_answer(params = {}) ⇒ Types::UpdateReviewTemplateAnswerOutput
Update a review template answer.
1361 |
# File 'sig/client.rbs', line 1361 def update_review_template_answer: ( |
#update_review_template_lens_review(params = {}) ⇒ Types::UpdateReviewTemplateLensReviewOutput
Update a lens review associated with a review template.
1383 |
# File 'sig/client.rbs', line 1383 def update_review_template_lens_review: ( |
#update_share_invitation(params = {}) ⇒ Types::UpdateShareInvitationOutput
Update a workload or custom lens share invitation.
1396 |
# File 'sig/client.rbs', line 1396 def update_share_invitation: ( |
#update_workload(params = {}) ⇒ Types::UpdateWorkloadOutput
Update an existing workload.
1407 |
# File 'sig/client.rbs', line 1407 def update_workload: ( |
#update_workload_share(params = {}) ⇒ Types::UpdateWorkloadShareOutput
Update a workload share.
1442 |
# File 'sig/client.rbs', line 1442 def update_workload_share: ( |
#upgrade_lens_review(params = {}) ⇒ Struct
Upgrade lens review for a particular workload.
1450 |
# File 'sig/client.rbs', line 1450 def upgrade_lens_review: ( |
#upgrade_profile_version(params = {}) ⇒ Struct
Upgrade a profile.
1459 |
# File 'sig/client.rbs', line 1459 def upgrade_profile_version: ( |
#upgrade_review_template_lens_review(params = {}) ⇒ Struct
Upgrade the lens review of a review template.
1468 |
# File 'sig/client.rbs', line 1468 def upgrade_review_template_lens_review: ( |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6782 6783 6784 |
# File 'lib/aws-sdk-wellarchitected/client.rb', line 6782 def waiter_names [] end |