Class: Aws::WellArchitected::Types::AgentRecommendationGenerationSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wellarchitected/types.rb

Overview

Summary of a recommendation generation process initiated through the agent API.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_at ⇒ Time

The timestamp when the generation was started.

Returns:

  • (Time)


263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/aws-sdk-wellarchitected/types.rb', line 263

class AgentRecommendationGenerationSummary < Struct.new(
  :id,
  :profile_arn,
  :name,
  :status,
  :estimated_completion_time,
  :created_by,
  :created_at,
  :last_modified_by,
  :last_modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_by ⇒ String

The identifier of the user or system that started this generation.

Returns:

  • (String)


263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/aws-sdk-wellarchitected/types.rb', line 263

class AgentRecommendationGenerationSummary < Struct.new(
  :id,
  :profile_arn,
  :name,
  :status,
  :estimated_completion_time,
  :created_by,
  :created_at,
  :last_modified_by,
  :last_modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#estimated_completion_time ⇒ Time

The estimated time for the generation to complete.

Returns:

  • (Time)


263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/aws-sdk-wellarchitected/types.rb', line 263

class AgentRecommendationGenerationSummary < Struct.new(
  :id,
  :profile_arn,
  :name,
  :status,
  :estimated_completion_time,
  :created_by,
  :created_at,
  :last_modified_by,
  :last_modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#id ⇒ String

The unique identifier of the recommendation generation.

Returns:

  • (String)


263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/aws-sdk-wellarchitected/types.rb', line 263

class AgentRecommendationGenerationSummary < Struct.new(
  :id,
  :profile_arn,
  :name,
  :status,
  :estimated_completion_time,
  :created_by,
  :created_at,
  :last_modified_by,
  :last_modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_at ⇒ Time

The timestamp when the generation was last modified.

Returns:

  • (Time)


263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/aws-sdk-wellarchitected/types.rb', line 263

class AgentRecommendationGenerationSummary < Struct.new(
  :id,
  :profile_arn,
  :name,
  :status,
  :estimated_completion_time,
  :created_by,
  :created_at,
  :last_modified_by,
  :last_modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_by ⇒ String

The identifier of the user or system that last modified this generation.

Returns:

  • (String)


263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/aws-sdk-wellarchitected/types.rb', line 263

class AgentRecommendationGenerationSummary < Struct.new(
  :id,
  :profile_arn,
  :name,
  :status,
  :estimated_completion_time,
  :created_by,
  :created_at,
  :last_modified_by,
  :last_modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the recommendation generation.

Returns:

  • (String)


263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/aws-sdk-wellarchitected/types.rb', line 263

class AgentRecommendationGenerationSummary < Struct.new(
  :id,
  :profile_arn,
  :name,
  :status,
  :estimated_completion_time,
  :created_by,
  :created_at,
  :last_modified_by,
  :last_modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#profile_arn ⇒ String

The Amazon Resource Name (ARN) of the profile used for this generation.

Returns:

  • (String)


263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/aws-sdk-wellarchitected/types.rb', line 263

class AgentRecommendationGenerationSummary < Struct.new(
  :id,
  :profile_arn,
  :name,
  :status,
  :estimated_completion_time,
  :created_by,
  :created_at,
  :last_modified_by,
  :last_modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The current status of the recommendation generation.

Returns:

  • (String)


263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/aws-sdk-wellarchitected/types.rb', line 263

class AgentRecommendationGenerationSummary < Struct.new(
  :id,
  :profile_arn,
  :name,
  :status,
  :estimated_completion_time,
  :created_by,
  :created_at,
  :last_modified_by,
  :last_modified_at)
  SENSITIVE = []
  include Aws::Structure
end