Class: Aws::WellArchitected::Types::AgentRecommendationItemSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wellarchitected/types.rb

Overview

Summary of an agent recommendation item, representing an Amazon Web Services resource or recommendation affected by the optimization recommendation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_at ⇒ Time

The timestamp when the recommendation item was created.

Returns:

  • (Time)


318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/aws-sdk-wellarchitected/types.rb', line 318

class AgentRecommendationItemSummary < Struct.new(
  :id,
  :recommendation_arn,
  :type,
  :metadata,
  :created_by,
  :created_at,
  :last_modified_by,
  :last_modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_by ⇒ String

The identifier of the user or system that created this recommendation item.

Returns:

  • (String)


318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/aws-sdk-wellarchitected/types.rb', line 318

class AgentRecommendationItemSummary < Struct.new(
  :id,
  :recommendation_arn,
  :type,
  :metadata,
  :created_by,
  :created_at,
  :last_modified_by,
  :last_modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#id ⇒ String

The unique identifier of the recommendation item.

Returns:

  • (String)


318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/aws-sdk-wellarchitected/types.rb', line 318

class AgentRecommendationItemSummary < Struct.new(
  :id,
  :recommendation_arn,
  :type,
  :metadata,
  :created_by,
  :created_at,
  :last_modified_by,
  :last_modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_at ⇒ Time

The timestamp when the recommendation item was last modified.

Returns:

  • (Time)


318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/aws-sdk-wellarchitected/types.rb', line 318

class AgentRecommendationItemSummary < Struct.new(
  :id,
  :recommendation_arn,
  :type,
  :metadata,
  :created_by,
  :created_at,
  :last_modified_by,
  :last_modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_by ⇒ String

The identifier of the user or system that last modified this recommendation item.

Returns:

  • (String)


318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/aws-sdk-wellarchitected/types.rb', line 318

class AgentRecommendationItemSummary < Struct.new(
  :id,
  :recommendation_arn,
  :type,
  :metadata,
  :created_by,
  :created_at,
  :last_modified_by,
  :last_modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#metadata ⇒ Hash, ...

Metadata containing a snapshot of the resource or recommendation at the time of generation.

Returns:

  • (Hash, Array, String, Numeric, Boolean)


318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/aws-sdk-wellarchitected/types.rb', line 318

class AgentRecommendationItemSummary < Struct.new(
  :id,
  :recommendation_arn,
  :type,
  :metadata,
  :created_by,
  :created_at,
  :last_modified_by,
  :last_modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#recommendation_arn ⇒ String

The Amazon Resource Name (ARN) of the associated recommendation.

Returns:

  • (String)


318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/aws-sdk-wellarchitected/types.rb', line 318

class AgentRecommendationItemSummary < Struct.new(
  :id,
  :recommendation_arn,
  :type,
  :metadata,
  :created_by,
  :created_at,
  :last_modified_by,
  :last_modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#type ⇒ String

The type of the recommendation item.

Returns:

  • (String)


318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/aws-sdk-wellarchitected/types.rb', line 318

class AgentRecommendationItemSummary < Struct.new(
  :id,
  :recommendation_arn,
  :type,
  :metadata,
  :created_by,
  :created_at,
  :last_modified_by,
  :last_modified_at)
  SENSITIVE = []
  include Aws::Structure
end