Class: Aws::WellArchitected::Types::AnswerSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wellarchitected/types.rb

Overview

An answer summary of a lens review in a workload.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#choice_answer_summaries ⇒ Array<Types::ChoiceAnswerSummary>

A list of selected choices to a question in your workload.

Returns:



689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
# File 'lib/aws-sdk-wellarchitected/types.rb', line 689

class AnswerSummary < Struct.new(
  :question_id,
  :pillar_id,
  :question_title,
  :choices,
  :selected_choices,
  :choice_answer_summaries,
  :is_applicable,
  :risk,
  :reason,
  :question_type,
  :jira_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#choices ⇒ Array<Types::Choice>

List of choices available for a question.

Returns:



689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
# File 'lib/aws-sdk-wellarchitected/types.rb', line 689

class AnswerSummary < Struct.new(
  :question_id,
  :pillar_id,
  :question_title,
  :choices,
  :selected_choices,
  :choice_answer_summaries,
  :is_applicable,
  :risk,
  :reason,
  :question_type,
  :jira_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#is_applicable ⇒ Boolean

Defines whether this question is applicable to a lens review.

Returns:

  • (Boolean)


689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
# File 'lib/aws-sdk-wellarchitected/types.rb', line 689

class AnswerSummary < Struct.new(
  :question_id,
  :pillar_id,
  :question_title,
  :choices,
  :selected_choices,
  :choice_answer_summaries,
  :is_applicable,
  :risk,
  :reason,
  :question_type,
  :jira_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#jira_configuration ⇒ Types::JiraConfiguration

Configuration of the Jira integration.



689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
# File 'lib/aws-sdk-wellarchitected/types.rb', line 689

class AnswerSummary < Struct.new(
  :question_id,
  :pillar_id,
  :question_title,
  :choices,
  :selected_choices,
  :choice_answer_summaries,
  :is_applicable,
  :risk,
  :reason,
  :question_type,
  :jira_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#pillar_id ⇒ String

The ID used to identify a pillar, for example, security.

A pillar is identified by its PillarReviewSummary$PillarId.

Returns:

  • (String)


689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
# File 'lib/aws-sdk-wellarchitected/types.rb', line 689

class AnswerSummary < Struct.new(
  :question_id,
  :pillar_id,
  :question_title,
  :choices,
  :selected_choices,
  :choice_answer_summaries,
  :is_applicable,
  :risk,
  :reason,
  :question_type,
  :jira_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#question_id ⇒ String

The ID of the question.

Returns:

  • (String)


689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
# File 'lib/aws-sdk-wellarchitected/types.rb', line 689

class AnswerSummary < Struct.new(
  :question_id,
  :pillar_id,
  :question_title,
  :choices,
  :selected_choices,
  :choice_answer_summaries,
  :is_applicable,
  :risk,
  :reason,
  :question_type,
  :jira_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#question_title ⇒ String

The title of the question.

Returns:

  • (String)


689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
# File 'lib/aws-sdk-wellarchitected/types.rb', line 689

class AnswerSummary < Struct.new(
  :question_id,
  :pillar_id,
  :question_title,
  :choices,
  :selected_choices,
  :choice_answer_summaries,
  :is_applicable,
  :risk,
  :reason,
  :question_type,
  :jira_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#question_type ⇒ String

The type of the question.

Returns:

  • (String)


689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
# File 'lib/aws-sdk-wellarchitected/types.rb', line 689

class AnswerSummary < Struct.new(
  :question_id,
  :pillar_id,
  :question_title,
  :choices,
  :selected_choices,
  :choice_answer_summaries,
  :is_applicable,
  :risk,
  :reason,
  :question_type,
  :jira_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#reason ⇒ String

The reason why a choice is non-applicable to a question in your workload.

Returns:

  • (String)


689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
# File 'lib/aws-sdk-wellarchitected/types.rb', line 689

class AnswerSummary < Struct.new(
  :question_id,
  :pillar_id,
  :question_title,
  :choices,
  :selected_choices,
  :choice_answer_summaries,
  :is_applicable,
  :risk,
  :reason,
  :question_type,
  :jira_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#risk ⇒ String

The risk for a given workload, lens review, pillar, or question.

Returns:

  • (String)


689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
# File 'lib/aws-sdk-wellarchitected/types.rb', line 689

class AnswerSummary < Struct.new(
  :question_id,
  :pillar_id,
  :question_title,
  :choices,
  :selected_choices,
  :choice_answer_summaries,
  :is_applicable,
  :risk,
  :reason,
  :question_type,
  :jira_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#selected_choices ⇒ Array<String>

List of selected choice IDs in a question answer.

The values entered replace the previously selected choices.

Returns:

  • (Array<String>)


689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
# File 'lib/aws-sdk-wellarchitected/types.rb', line 689

class AnswerSummary < Struct.new(
  :question_id,
  :pillar_id,
  :question_title,
  :choices,
  :selected_choices,
  :choice_answer_summaries,
  :is_applicable,
  :risk,
  :reason,
  :question_type,
  :jira_configuration)
  SENSITIVE = []
  include Aws::Structure
end