Class: Aws::WellArchitected::Types::CheckSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wellarchitected/types.rb

Overview

Trusted Advisor check summary.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_summary ⇒ Hash<String,Integer>

Account summary associated to the check.

Returns:

  • (Hash<String,Integer>)


893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
# File 'lib/aws-sdk-wellarchitected/types.rb', line 893

class CheckSummary < Struct.new(
  :id,
  :name,
  :provider,
  :description,
  :updated_at,
  :lens_arn,
  :pillar_id,
  :question_id,
  :choice_id,
  :status,
  :account_summary)
  SENSITIVE = []
  include Aws::Structure
end

#choice_id ⇒ String

The ID of a choice.

Returns:

  • (String)


893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
# File 'lib/aws-sdk-wellarchitected/types.rb', line 893

class CheckSummary < Struct.new(
  :id,
  :name,
  :provider,
  :description,
  :updated_at,
  :lens_arn,
  :pillar_id,
  :question_id,
  :choice_id,
  :status,
  :account_summary)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

Trusted Advisor check description.

Returns:

  • (String)


893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
# File 'lib/aws-sdk-wellarchitected/types.rb', line 893

class CheckSummary < Struct.new(
  :id,
  :name,
  :provider,
  :description,
  :updated_at,
  :lens_arn,
  :pillar_id,
  :question_id,
  :choice_id,
  :status,
  :account_summary)
  SENSITIVE = []
  include Aws::Structure
end

#id ⇒ String

Trusted Advisor check ID.

Returns:

  • (String)


893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
# File 'lib/aws-sdk-wellarchitected/types.rb', line 893

class CheckSummary < Struct.new(
  :id,
  :name,
  :provider,
  :description,
  :updated_at,
  :lens_arn,
  :pillar_id,
  :question_id,
  :choice_id,
  :status,
  :account_summary)
  SENSITIVE = []
  include Aws::Structure
end

#lens_arn ⇒ String

Well-Architected Lens ARN associated to the check.

Returns:

  • (String)


893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
# File 'lib/aws-sdk-wellarchitected/types.rb', line 893

class CheckSummary < Struct.new(
  :id,
  :name,
  :provider,
  :description,
  :updated_at,
  :lens_arn,
  :pillar_id,
  :question_id,
  :choice_id,
  :status,
  :account_summary)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

Trusted Advisor check name.

Returns:

  • (String)


893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
# File 'lib/aws-sdk-wellarchitected/types.rb', line 893

class CheckSummary < Struct.new(
  :id,
  :name,
  :provider,
  :description,
  :updated_at,
  :lens_arn,
  :pillar_id,
  :question_id,
  :choice_id,
  :status,
  :account_summary)
  SENSITIVE = []
  include Aws::Structure
end

#pillar_id ⇒ String

The ID used to identify a pillar, for example, security.

A pillar is identified by its PillarReviewSummary$PillarId.

Returns:

  • (String)


893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
# File 'lib/aws-sdk-wellarchitected/types.rb', line 893

class CheckSummary < Struct.new(
  :id,
  :name,
  :provider,
  :description,
  :updated_at,
  :lens_arn,
  :pillar_id,
  :question_id,
  :choice_id,
  :status,
  :account_summary)
  SENSITIVE = []
  include Aws::Structure
end

#provider ⇒ String

Provider of the check related to the best practice.

Returns:

  • (String)


893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
# File 'lib/aws-sdk-wellarchitected/types.rb', line 893

class CheckSummary < Struct.new(
  :id,
  :name,
  :provider,
  :description,
  :updated_at,
  :lens_arn,
  :pillar_id,
  :question_id,
  :choice_id,
  :status,
  :account_summary)
  SENSITIVE = []
  include Aws::Structure
end

#question_id ⇒ String

The ID of the question.

Returns:

  • (String)


893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
# File 'lib/aws-sdk-wellarchitected/types.rb', line 893

class CheckSummary < Struct.new(
  :id,
  :name,
  :provider,
  :description,
  :updated_at,
  :lens_arn,
  :pillar_id,
  :question_id,
  :choice_id,
  :status,
  :account_summary)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

Status associated to the check.

Returns:

  • (String)


893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
# File 'lib/aws-sdk-wellarchitected/types.rb', line 893

class CheckSummary < Struct.new(
  :id,
  :name,
  :provider,
  :description,
  :updated_at,
  :lens_arn,
  :pillar_id,
  :question_id,
  :choice_id,
  :status,
  :account_summary)
  SENSITIVE = []
  include Aws::Structure
end

#updated_at ⇒ Time

The date and time when the check summary was last updated.

Returns:

  • (Time)


893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
# File 'lib/aws-sdk-wellarchitected/types.rb', line 893

class CheckSummary < Struct.new(
  :id,
  :name,
  :provider,
  :description,
  :updated_at,
  :lens_arn,
  :pillar_id,
  :question_id,
  :choice_id,
  :status,
  :account_summary)
  SENSITIVE = []
  include Aws::Structure
end