Class: Aws::WellArchitected::Types::ContextSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wellarchitected/types.rb

Overview

Summary of a context associated with a profile, representing application or environment information used during recommendation generation.

Constant Summary collapse

SENSITIVE =
[:title]

Instance Attribute Summary collapse

Instance Attribute Details

#application_type ⇒ String

The type of application described by this context.

Returns:

  • (String)


1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
# File 'lib/aws-sdk-wellarchitected/types.rb', line 1307

class ContextSummary < Struct.new(
  :id,
  :profile_arn,
  :title,
  :context_type,
  :content,
  :application_type,
  :criticality,
  :created_by,
  :created_at,
  :last_modified_by,
  :last_modified_at)
  SENSITIVE = [:title]
  include Aws::Structure
end

#content ⇒ Types::ContextContent

The typed content of the context, containing application-specific fields such as account IDs, Regions, services, and resource types.



1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
# File 'lib/aws-sdk-wellarchitected/types.rb', line 1307

class ContextSummary < Struct.new(
  :id,
  :profile_arn,
  :title,
  :context_type,
  :content,
  :application_type,
  :criticality,
  :created_by,
  :created_at,
  :last_modified_by,
  :last_modified_at)
  SENSITIVE = [:title]
  include Aws::Structure
end

#context_type ⇒ String

The type of the context.

Returns:

  • (String)


1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
# File 'lib/aws-sdk-wellarchitected/types.rb', line 1307

class ContextSummary < Struct.new(
  :id,
  :profile_arn,
  :title,
  :context_type,
  :content,
  :application_type,
  :criticality,
  :created_by,
  :created_at,
  :last_modified_by,
  :last_modified_at)
  SENSITIVE = [:title]
  include Aws::Structure
end

#created_at ⇒ Time

The timestamp when the context was created.

Returns:

  • (Time)


1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
# File 'lib/aws-sdk-wellarchitected/types.rb', line 1307

class ContextSummary < Struct.new(
  :id,
  :profile_arn,
  :title,
  :context_type,
  :content,
  :application_type,
  :criticality,
  :created_by,
  :created_at,
  :last_modified_by,
  :last_modified_at)
  SENSITIVE = [:title]
  include Aws::Structure
end

#created_by ⇒ String

The identifier of the user or system that created this context.

Returns:

  • (String)


1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
# File 'lib/aws-sdk-wellarchitected/types.rb', line 1307

class ContextSummary < Struct.new(
  :id,
  :profile_arn,
  :title,
  :context_type,
  :content,
  :application_type,
  :criticality,
  :created_by,
  :created_at,
  :last_modified_by,
  :last_modified_at)
  SENSITIVE = [:title]
  include Aws::Structure
end

#criticality ⇒ String

The business criticality of the application described by this context.

Returns:

  • (String)


1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
# File 'lib/aws-sdk-wellarchitected/types.rb', line 1307

class ContextSummary < Struct.new(
  :id,
  :profile_arn,
  :title,
  :context_type,
  :content,
  :application_type,
  :criticality,
  :created_by,
  :created_at,
  :last_modified_by,
  :last_modified_at)
  SENSITIVE = [:title]
  include Aws::Structure
end

#id ⇒ String

The unique identifier of the context.

Returns:

  • (String)


1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
# File 'lib/aws-sdk-wellarchitected/types.rb', line 1307

class ContextSummary < Struct.new(
  :id,
  :profile_arn,
  :title,
  :context_type,
  :content,
  :application_type,
  :criticality,
  :created_by,
  :created_at,
  :last_modified_by,
  :last_modified_at)
  SENSITIVE = [:title]
  include Aws::Structure
end

#last_modified_at ⇒ Time

The timestamp when the context was last modified.

Returns:

  • (Time)


1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
# File 'lib/aws-sdk-wellarchitected/types.rb', line 1307

class ContextSummary < Struct.new(
  :id,
  :profile_arn,
  :title,
  :context_type,
  :content,
  :application_type,
  :criticality,
  :created_by,
  :created_at,
  :last_modified_by,
  :last_modified_at)
  SENSITIVE = [:title]
  include Aws::Structure
end

#last_modified_by ⇒ String

The identifier of the user or system that last modified this context.

Returns:

  • (String)


1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
# File 'lib/aws-sdk-wellarchitected/types.rb', line 1307

class ContextSummary < Struct.new(
  :id,
  :profile_arn,
  :title,
  :context_type,
  :content,
  :application_type,
  :criticality,
  :created_by,
  :created_at,
  :last_modified_by,
  :last_modified_at)
  SENSITIVE = [:title]
  include Aws::Structure
end

#profile_arn ⇒ String

The Amazon Resource Name (ARN) of the associated profile.

Returns:

  • (String)


1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
# File 'lib/aws-sdk-wellarchitected/types.rb', line 1307

class ContextSummary < Struct.new(
  :id,
  :profile_arn,
  :title,
  :context_type,
  :content,
  :application_type,
  :criticality,
  :created_by,
  :created_at,
  :last_modified_by,
  :last_modified_at)
  SENSITIVE = [:title]
  include Aws::Structure
end

#title ⇒ String

The title of the context.

Returns:

  • (String)


1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
# File 'lib/aws-sdk-wellarchitected/types.rb', line 1307

class ContextSummary < Struct.new(
  :id,
  :profile_arn,
  :title,
  :context_type,
  :content,
  :application_type,
  :criticality,
  :created_by,
  :created_at,
  :last_modified_by,
  :last_modified_at)
  SENSITIVE = [:title]
  include Aws::Structure
end