Class: Aws::WellArchitected::Types::CreateAgentGoalRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wellarchitected/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:title, :description]

Instance Attribute Summary collapse

Instance Attribute Details

#client_token ⇒ String

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


1402
1403
1404
1405
1406
1407
1408
1409
1410
# File 'lib/aws-sdk-wellarchitected/types.rb', line 1402

class CreateAgentGoalRequest < Struct.new(
  :client_token,
  :profile_arn,
  :pillars,
  :title,
  :description)
  SENSITIVE = [:title, :description]
  include Aws::Structure
end

#description ⇒ String

A description of the goal.

Returns:

  • (String)


1402
1403
1404
1405
1406
1407
1408
1409
1410
# File 'lib/aws-sdk-wellarchitected/types.rb', line 1402

class CreateAgentGoalRequest < Struct.new(
  :client_token,
  :profile_arn,
  :pillars,
  :title,
  :description)
  SENSITIVE = [:title, :description]
  include Aws::Structure
end

#pillars ⇒ Array<String>

The Well-Architected Tool Framework pillars to associate with this goal.

Returns:

  • (Array<String>)


1402
1403
1404
1405
1406
1407
1408
1409
1410
# File 'lib/aws-sdk-wellarchitected/types.rb', line 1402

class CreateAgentGoalRequest < Struct.new(
  :client_token,
  :profile_arn,
  :pillars,
  :title,
  :description)
  SENSITIVE = [:title, :description]
  include Aws::Structure
end

#profile_arn ⇒ String

The Amazon Resource Name (ARN) of the profile to associate the goal with.

Returns:

  • (String)


1402
1403
1404
1405
1406
1407
1408
1409
1410
# File 'lib/aws-sdk-wellarchitected/types.rb', line 1402

class CreateAgentGoalRequest < Struct.new(
  :client_token,
  :profile_arn,
  :pillars,
  :title,
  :description)
  SENSITIVE = [:title, :description]
  include Aws::Structure
end

#title ⇒ String

The title of the goal.

Returns:

  • (String)


1402
1403
1404
1405
1406
1407
1408
1409
1410
# File 'lib/aws-sdk-wellarchitected/types.rb', line 1402

class CreateAgentGoalRequest < Struct.new(
  :client_token,
  :profile_arn,
  :pillars,
  :title,
  :description)
  SENSITIVE = [:title, :description]
  include Aws::Structure
end