Class: Aws::WellArchitected::Types::CreateLensVersionInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wellarchitected/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_request_token ⇒ String

A unique case-sensitive string used to ensure that this request is idempotent (executes only once).

You should not reuse the same token for other requests. If you retry a request with the same client request token and the same parameters after the original request has completed successfully, the result of the original request is returned.

This token is listed as required, however, if you do not specify it, the Amazon Web Services SDKs automatically generate one for you. If you are not using the Amazon Web Services SDK or the CLI, you must provide this token or the request will fail.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


1688
1689
1690
1691
1692
1693
1694
1695
# File 'lib/aws-sdk-wellarchitected/types.rb', line 1688

class CreateLensVersionInput < Struct.new(
  :lens_alias,
  :lens_version,
  :is_major_version,
  :client_request_token)
  SENSITIVE = []
  include Aws::Structure
end

#is_major_version ⇒ Boolean

Set to true if this new major lens version.

Returns:

  • (Boolean)


1688
1689
1690
1691
1692
1693
1694
1695
# File 'lib/aws-sdk-wellarchitected/types.rb', line 1688

class CreateLensVersionInput < Struct.new(
  :lens_alias,
  :lens_version,
  :is_major_version,
  :client_request_token)
  SENSITIVE = []
  include Aws::Structure
end

#lens_alias ⇒ String

The alias of the lens.

For Amazon Web Services official lenses, this is either the lens alias, such as serverless, or the lens ARN, such as arn:aws:wellarchitected:us-east-1::lens/serverless. Note that some operations (such as ExportLens and CreateLensShare) are not permitted on Amazon Web Services official lenses.

For custom lenses, this is the lens ARN, such as arn:aws:wellarchitected:us-west-2:123456789012:lens/0123456789abcdef01234567890abcdef.

Each lens is identified by its LensSummary$LensAlias.

Returns:

  • (String)


1688
1689
1690
1691
1692
1693
1694
1695
# File 'lib/aws-sdk-wellarchitected/types.rb', line 1688

class CreateLensVersionInput < Struct.new(
  :lens_alias,
  :lens_version,
  :is_major_version,
  :client_request_token)
  SENSITIVE = []
  include Aws::Structure
end

#lens_version ⇒ String

The version of the lens being created.

Returns:

  • (String)


1688
1689
1690
1691
1692
1693
1694
1695
# File 'lib/aws-sdk-wellarchitected/types.rb', line 1688

class CreateLensVersionInput < Struct.new(
  :lens_alias,
  :lens_version,
  :is_major_version,
  :client_request_token)
  SENSITIVE = []
  include Aws::Structure
end