Class: Aws::WellArchitected::Types::CreateWorkloadShareInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::WellArchitected::Types::CreateWorkloadShareInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wellarchitected/types.rb
Overview
Input for Create Workload Share
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_request_token ⇒ String
A unique case-sensitive string used to ensure that this request is idempotent (executes only once).
-
#permission_type ⇒ String
Permission granted on a share request.
-
#shared_with ⇒ String
The Amazon Web Services account ID, organization ID, or organizational unit (OU) ID with which the workload, lens, profile, or review template is shared.
-
#workload_id ⇒ String
The ID assigned to the workload.
Instance Attribute Details
#client_request_token ⇒ String
A unique case-sensitive string used to ensure that this request is idempotent (executes only once).
You should not reuse the same token for other requests. If you retry a request with the same client request token and the same parameters after the original request has completed successfully, the result of the original request is returned.
This token is listed as required, however, if you do not specify it, the Amazon Web Services SDKs automatically generate one for you. If you are not using the Amazon Web Services SDK or the CLI, you must provide this token or the request will fail.
A suitable default value is auto-generated. You should normally not need to pass this option.
2272 2273 2274 2275 2276 2277 2278 2279 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 2272 class CreateWorkloadShareInput < Struct.new( :workload_id, :shared_with, :permission_type, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#permission_type ⇒ String
Permission granted on a share request.
2272 2273 2274 2275 2276 2277 2278 2279 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 2272 class CreateWorkloadShareInput < Struct.new( :workload_id, :shared_with, :permission_type, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#shared_with ⇒ String
The Amazon Web Services account ID, organization ID, or organizational unit (OU) ID with which the workload, lens, profile, or review template is shared.
2272 2273 2274 2275 2276 2277 2278 2279 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 2272 class CreateWorkloadShareInput < Struct.new( :workload_id, :shared_with, :permission_type, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#workload_id ⇒ String
The ID assigned to the workload. This ID is unique within an Amazon Web Services Region.
2272 2273 2274 2275 2276 2277 2278 2279 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 2272 class CreateWorkloadShareInput < Struct.new( :workload_id, :shared_with, :permission_type, :client_request_token) SENSITIVE = [] include Aws::Structure end |