Class: Aws::WellArchitected::Types::CrossPillarBenefit

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wellarchitected/types.rb

Overview

A benefit on a different pillar from acting on the recommendation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#description ⇒ String

A description of what changes and why it matters.

Returns:

  • (String)


2321
2322
2323
2324
2325
2326
2327
2328
# File 'lib/aws-sdk-wellarchitected/types.rb', line 2321

class CrossPillarBenefit < Struct.new(
  :pillar,
  :title,
  :description,
  :impact)
  SENSITIVE = []
  include Aws::Structure
end

#impact ⇒ String

The severity of the benefit.

Returns:

  • (String)


2321
2322
2323
2324
2325
2326
2327
2328
# File 'lib/aws-sdk-wellarchitected/types.rb', line 2321

class CrossPillarBenefit < Struct.new(
  :pillar,
  :title,
  :description,
  :impact)
  SENSITIVE = []
  include Aws::Structure
end

#pillar ⇒ String

The pillar that would be positively impacted.

Returns:

  • (String)


2321
2322
2323
2324
2325
2326
2327
2328
# File 'lib/aws-sdk-wellarchitected/types.rb', line 2321

class CrossPillarBenefit < Struct.new(
  :pillar,
  :title,
  :description,
  :impact)
  SENSITIVE = []
  include Aws::Structure
end

#title ⇒ String

A short phrase describing the outcome.

Returns:

  • (String)


2321
2322
2323
2324
2325
2326
2327
2328
# File 'lib/aws-sdk-wellarchitected/types.rb', line 2321

class CrossPillarBenefit < Struct.new(
  :pillar,
  :title,
  :description,
  :impact)
  SENSITIVE = []
  include Aws::Structure
end