Class: Aws::WellArchitected::Types::JiraConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::WellArchitected::Types::JiraConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wellarchitected/types.rb
Overview
Configuration of the Jira integration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#jira_issue_url ⇒ String
The URL of the associated Jira issue.
-
#last_synced_time ⇒ Time
The date and time when the Jira configuration was last synced.
Instance Attribute Details
#jira_issue_url ⇒ String
The URL of the associated Jira issue.
4150 4151 4152 4153 4154 4155 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 4150 class JiraConfiguration < Struct.new( :jira_issue_url, :last_synced_time) SENSITIVE = [] include Aws::Structure end |
#last_synced_time ⇒ Time
The date and time when the Jira configuration was last synced.
4150 4151 4152 4153 4154 4155 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 4150 class JiraConfiguration < Struct.new( :jira_issue_url, :last_synced_time) SENSITIVE = [] include Aws::Structure end |