Class: Aws::WellArchitected::Types::LensMetric

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wellarchitected/types.rb

Overview

A metric for a particular lens in a workload.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#lens_arn ⇒ String

The lens ARN.

Returns:

  • (String)


4232
4233
4234
4235
4236
4237
4238
# File 'lib/aws-sdk-wellarchitected/types.rb', line 4232

class LensMetric < Struct.new(
  :lens_arn,
  :pillars,
  :risk_counts)
  SENSITIVE = []
  include Aws::Structure
end

#pillars ⇒ Array<Types::PillarMetric>

The metrics for the pillars in a lens.

Returns:



4232
4233
4234
4235
4236
4237
4238
# File 'lib/aws-sdk-wellarchitected/types.rb', line 4232

class LensMetric < Struct.new(
  :lens_arn,
  :pillars,
  :risk_counts)
  SENSITIVE = []
  include Aws::Structure
end

#risk_counts ⇒ Hash<String,Integer>

A map from risk names to the count of how many questions have that rating.

Returns:

  • (Hash<String,Integer>)


4232
4233
4234
4235
4236
4237
4238
# File 'lib/aws-sdk-wellarchitected/types.rb', line 4232

class LensMetric < Struct.new(
  :lens_arn,
  :pillars,
  :risk_counts)
  SENSITIVE = []
  include Aws::Structure
end