Class: Aws::WellArchitected::Types::LensShareSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::WellArchitected::Types::LensShareSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wellarchitected/types.rb
Overview
A lens share summary return object.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#share_id ⇒ String
The ID associated with the share.
-
#shared_with ⇒ String
The Amazon Web Services account ID, organization ID, or organizational unit (OU) ID with which the workload, lens, profile, or review template is shared.
-
#status ⇒ String
The status of the share request.
-
#status_message ⇒ String
Optional message to compliment the Status field.
Instance Attribute Details
#share_id ⇒ String
The ID associated with the share.
4459 4460 4461 4462 4463 4464 4465 4466 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 4459 class LensShareSummary < Struct.new( :share_id, :shared_with, :status, :status_message) SENSITIVE = [] include Aws::Structure end |
#shared_with ⇒ String
The Amazon Web Services account ID, organization ID, or organizational unit (OU) ID with which the workload, lens, profile, or review template is shared.
4459 4460 4461 4462 4463 4464 4465 4466 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 4459 class LensShareSummary < Struct.new( :share_id, :shared_with, :status, :status_message) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the share request.
4459 4460 4461 4462 4463 4464 4465 4466 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 4459 class LensShareSummary < Struct.new( :share_id, :shared_with, :status, :status_message) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
Optional message to compliment the Status field.
4459 4460 4461 4462 4463 4464 4465 4466 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 4459 class LensShareSummary < Struct.new( :share_id, :shared_with, :status, :status_message) SENSITIVE = [] include Aws::Structure end |