Class: Aws::WellArchitected::Types::ListCheckSummariesInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wellarchitected/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#choice_id ⇒ String

The ID of a choice.

Returns:

  • (String)


5075
5076
5077
5078
5079
5080
5081
5082
5083
5084
5085
# File 'lib/aws-sdk-wellarchitected/types.rb', line 5075

class ListCheckSummariesInput < Struct.new(
  :workload_id,
  :next_token,
  :max_results,
  :lens_arn,
  :pillar_id,
  :question_id,
  :choice_id)
  SENSITIVE = []
  include Aws::Structure
end

#lens_arn ⇒ String

Well-Architected Lens ARN.

Returns:

  • (String)


5075
5076
5077
5078
5079
5080
5081
5082
5083
5084
5085
# File 'lib/aws-sdk-wellarchitected/types.rb', line 5075

class ListCheckSummariesInput < Struct.new(
  :workload_id,
  :next_token,
  :max_results,
  :lens_arn,
  :pillar_id,
  :question_id,
  :choice_id)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of results to return for this request.

Returns:

  • (Integer)


5075
5076
5077
5078
5079
5080
5081
5082
5083
5084
5085
# File 'lib/aws-sdk-wellarchitected/types.rb', line 5075

class ListCheckSummariesInput < Struct.new(
  :workload_id,
  :next_token,
  :max_results,
  :lens_arn,
  :pillar_id,
  :question_id,
  :choice_id)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The token to use to retrieve the next set of results.

Returns:

  • (String)


5075
5076
5077
5078
5079
5080
5081
5082
5083
5084
5085
# File 'lib/aws-sdk-wellarchitected/types.rb', line 5075

class ListCheckSummariesInput < Struct.new(
  :workload_id,
  :next_token,
  :max_results,
  :lens_arn,
  :pillar_id,
  :question_id,
  :choice_id)
  SENSITIVE = []
  include Aws::Structure
end

#pillar_id ⇒ String

The ID used to identify a pillar, for example, security.

A pillar is identified by its PillarReviewSummary$PillarId.

Returns:

  • (String)


5075
5076
5077
5078
5079
5080
5081
5082
5083
5084
5085
# File 'lib/aws-sdk-wellarchitected/types.rb', line 5075

class ListCheckSummariesInput < Struct.new(
  :workload_id,
  :next_token,
  :max_results,
  :lens_arn,
  :pillar_id,
  :question_id,
  :choice_id)
  SENSITIVE = []
  include Aws::Structure
end

#question_id ⇒ String

The ID of the question.

Returns:

  • (String)


5075
5076
5077
5078
5079
5080
5081
5082
5083
5084
5085
# File 'lib/aws-sdk-wellarchitected/types.rb', line 5075

class ListCheckSummariesInput < Struct.new(
  :workload_id,
  :next_token,
  :max_results,
  :lens_arn,
  :pillar_id,
  :question_id,
  :choice_id)
  SENSITIVE = []
  include Aws::Structure
end

#workload_id ⇒ String

The ID assigned to the workload. This ID is unique within an Amazon Web Services Region.

Returns:

  • (String)


5075
5076
5077
5078
5079
5080
5081
5082
5083
5084
5085
# File 'lib/aws-sdk-wellarchitected/types.rb', line 5075

class ListCheckSummariesInput < Struct.new(
  :workload_id,
  :next_token,
  :max_results,
  :lens_arn,
  :pillar_id,
  :question_id,
  :choice_id)
  SENSITIVE = []
  include Aws::Structure
end