Class: Aws::WellArchitected::Types::ListLensReviewImprovementsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::WellArchitected::Types::ListLensReviewImprovementsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wellarchitected/types.rb
Overview
Input to list lens review improvements.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#lens_alias ⇒ String
The alias of the lens.
-
#max_results ⇒ Integer
The maximum number of results to return for this request.
-
#milestone_number ⇒ Integer
The milestone number.
-
#next_token ⇒ String
The token to use to retrieve the next set of results.
-
#pillar_id ⇒ String
The ID used to identify a pillar, for example,
security. -
#question_priority ⇒ String
The priority of the question.
-
#workload_id ⇒ String
The ID assigned to the workload.
Instance Attribute Details
#lens_alias ⇒ String
The alias of the lens.
For Amazon Web Services official lenses, this is either the lens
alias, such as serverless, or the lens ARN, such as
arn:aws:wellarchitected:us-east-1::lens/serverless. Note that some
operations (such as ExportLens and CreateLensShare) are not
permitted on Amazon Web Services official lenses.
For custom lenses, this is the lens ARN, such as
arn:aws:wellarchitected:us-west-2:123456789012:lens/0123456789abcdef01234567890abcdef.
Each lens is identified by its LensSummary$LensAlias.
5165 5166 5167 5168 5169 5170 5171 5172 5173 5174 5175 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 5165 class ListLensReviewImprovementsInput < Struct.new( :workload_id, :lens_alias, :pillar_id, :milestone_number, :next_token, :max_results, :question_priority) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return for this request.
5165 5166 5167 5168 5169 5170 5171 5172 5173 5174 5175 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 5165 class ListLensReviewImprovementsInput < Struct.new( :workload_id, :lens_alias, :pillar_id, :milestone_number, :next_token, :max_results, :question_priority) SENSITIVE = [] include Aws::Structure end |
#milestone_number ⇒ Integer
The milestone number.
A workload can have a maximum of 100 milestones.
5165 5166 5167 5168 5169 5170 5171 5172 5173 5174 5175 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 5165 class ListLensReviewImprovementsInput < Struct.new( :workload_id, :lens_alias, :pillar_id, :milestone_number, :next_token, :max_results, :question_priority) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to use to retrieve the next set of results.
5165 5166 5167 5168 5169 5170 5171 5172 5173 5174 5175 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 5165 class ListLensReviewImprovementsInput < Struct.new( :workload_id, :lens_alias, :pillar_id, :milestone_number, :next_token, :max_results, :question_priority) SENSITIVE = [] include Aws::Structure end |
#pillar_id ⇒ String
The ID used to identify a pillar, for example, security.
A pillar is identified by its PillarReviewSummary$PillarId.
5165 5166 5167 5168 5169 5170 5171 5172 5173 5174 5175 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 5165 class ListLensReviewImprovementsInput < Struct.new( :workload_id, :lens_alias, :pillar_id, :milestone_number, :next_token, :max_results, :question_priority) SENSITIVE = [] include Aws::Structure end |
#question_priority ⇒ String
The priority of the question.
5165 5166 5167 5168 5169 5170 5171 5172 5173 5174 5175 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 5165 class ListLensReviewImprovementsInput < Struct.new( :workload_id, :lens_alias, :pillar_id, :milestone_number, :next_token, :max_results, :question_priority) SENSITIVE = [] include Aws::Structure end |
#workload_id ⇒ String
The ID assigned to the workload. This ID is unique within an Amazon Web Services Region.
5165 5166 5167 5168 5169 5170 5171 5172 5173 5174 5175 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 5165 class ListLensReviewImprovementsInput < Struct.new( :workload_id, :lens_alias, :pillar_id, :milestone_number, :next_token, :max_results, :question_priority) SENSITIVE = [] include Aws::Structure end |