Class: Aws::WellArchitected::Types::ListLensSharesOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::WellArchitected::Types::ListLensSharesOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wellarchitected/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#lens_share_summaries ⇒ Array<Types::LensShareSummary>
A list of lens share summaries.
-
#next_token ⇒ String
The token to use to retrieve the next set of results.
Instance Attribute Details
#lens_share_summaries ⇒ Array<Types::LensShareSummary>
A list of lens share summaries.
5348 5349 5350 5351 5352 5353 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 5348 class ListLensSharesOutput < Struct.new( :lens_share_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to use to retrieve the next set of results.
5348 5349 5350 5351 5352 5353 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 5348 class ListLensSharesOutput < Struct.new( :lens_share_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |