Class: Aws::WellArchitected::Types::ListMilestonesInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wellarchitected/types.rb

Overview

Input to list all milestones for a workload.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_results ⇒ Integer

The maximum number of results to return for this request.

Returns:

  • (Integer)


5425
5426
5427
5428
5429
5430
5431
# File 'lib/aws-sdk-wellarchitected/types.rb', line 5425

class ListMilestonesInput < Struct.new(
  :workload_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The token to use to retrieve the next set of results.

Returns:

  • (String)


5425
5426
5427
5428
5429
5430
5431
# File 'lib/aws-sdk-wellarchitected/types.rb', line 5425

class ListMilestonesInput < Struct.new(
  :workload_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#workload_id ⇒ String

The ID assigned to the workload. This ID is unique within an Amazon Web Services Region.

Returns:

  • (String)


5425
5426
5427
5428
5429
5430
5431
# File 'lib/aws-sdk-wellarchitected/types.rb', line 5425

class ListMilestonesInput < Struct.new(
  :workload_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end