Class: Aws::WellArchitected::Types::ListProfileSharesOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::WellArchitected::Types::ListProfileSharesOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wellarchitected/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to use to retrieve the next set of results.
-
#profile_share_summaries ⇒ Array<Types::ProfileShareSummary>
Profile share summaries.
Instance Attribute Details
#next_token ⇒ String
The token to use to retrieve the next set of results.
5590 5591 5592 5593 5594 5595 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 5590 class ListProfileSharesOutput < Struct.new( :profile_share_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#profile_share_summaries ⇒ Array<Types::ProfileShareSummary>
Profile share summaries.
5590 5591 5592 5593 5594 5595 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 5590 class ListProfileSharesOutput < Struct.new( :profile_share_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |