Class: Aws::WellArchitected::Types::ListProfilesInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wellarchitected/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_results ⇒ Integer

The maximum number of results to return for this request.

Returns:

  • (Integer)


5616
5617
5618
5619
5620
5621
5622
5623
# File 'lib/aws-sdk-wellarchitected/types.rb', line 5616

class ListProfilesInput < Struct.new(
  :profile_name_prefix,
  :profile_owner_type,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The token to use to retrieve the next set of results.

Returns:

  • (String)


5616
5617
5618
5619
5620
5621
5622
5623
# File 'lib/aws-sdk-wellarchitected/types.rb', line 5616

class ListProfilesInput < Struct.new(
  :profile_name_prefix,
  :profile_owner_type,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#profile_name_prefix ⇒ String

An optional string added to the beginning of each profile name returned in the results.

Returns:

  • (String)


5616
5617
5618
5619
5620
5621
5622
5623
# File 'lib/aws-sdk-wellarchitected/types.rb', line 5616

class ListProfilesInput < Struct.new(
  :profile_name_prefix,
  :profile_owner_type,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#profile_owner_type ⇒ String

Profile owner type.

Returns:

  • (String)


5616
5617
5618
5619
5620
5621
5622
5623
# File 'lib/aws-sdk-wellarchitected/types.rb', line 5616

class ListProfilesInput < Struct.new(
  :profile_name_prefix,
  :profile_owner_type,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end