Class: Aws::WellArchitected::Types::ListShareInvitationsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::WellArchitected::Types::ListShareInvitationsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wellarchitected/types.rb
Overview
Input for List Share Invitations
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#lens_name_prefix ⇒ String
An optional string added to the beginning of each lens name returned in the results.
-
#max_results ⇒ Integer
The maximum number of results to return for this request.
-
#next_token ⇒ String
The token to use to retrieve the next set of results.
-
#profile_name_prefix ⇒ String
An optional string added to the beginning of each profile name returned in the results.
-
#share_resource_type ⇒ String
The type of share invitations to be returned.
-
#template_name_prefix ⇒ String
An optional string added to the beginning of each review template name returned in the results.
-
#workload_name_prefix ⇒ String
An optional string added to the beginning of each workload name returned in the results.
Instance Attribute Details
#lens_name_prefix ⇒ String
An optional string added to the beginning of each lens name returned in the results.
5795 5796 5797 5798 5799 5800 5801 5802 5803 5804 5805 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 5795 class ListShareInvitationsInput < Struct.new( :workload_name_prefix, :lens_name_prefix, :share_resource_type, :next_token, :max_results, :profile_name_prefix, :template_name_prefix) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return for this request.
5795 5796 5797 5798 5799 5800 5801 5802 5803 5804 5805 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 5795 class ListShareInvitationsInput < Struct.new( :workload_name_prefix, :lens_name_prefix, :share_resource_type, :next_token, :max_results, :profile_name_prefix, :template_name_prefix) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to use to retrieve the next set of results.
5795 5796 5797 5798 5799 5800 5801 5802 5803 5804 5805 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 5795 class ListShareInvitationsInput < Struct.new( :workload_name_prefix, :lens_name_prefix, :share_resource_type, :next_token, :max_results, :profile_name_prefix, :template_name_prefix) SENSITIVE = [] include Aws::Structure end |
#profile_name_prefix ⇒ String
An optional string added to the beginning of each profile name returned in the results.
5795 5796 5797 5798 5799 5800 5801 5802 5803 5804 5805 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 5795 class ListShareInvitationsInput < Struct.new( :workload_name_prefix, :lens_name_prefix, :share_resource_type, :next_token, :max_results, :profile_name_prefix, :template_name_prefix) SENSITIVE = [] include Aws::Structure end |
#share_resource_type ⇒ String
The type of share invitations to be returned.
5795 5796 5797 5798 5799 5800 5801 5802 5803 5804 5805 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 5795 class ListShareInvitationsInput < Struct.new( :workload_name_prefix, :lens_name_prefix, :share_resource_type, :next_token, :max_results, :profile_name_prefix, :template_name_prefix) SENSITIVE = [] include Aws::Structure end |
#template_name_prefix ⇒ String
An optional string added to the beginning of each review template name returned in the results.
5795 5796 5797 5798 5799 5800 5801 5802 5803 5804 5805 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 5795 class ListShareInvitationsInput < Struct.new( :workload_name_prefix, :lens_name_prefix, :share_resource_type, :next_token, :max_results, :profile_name_prefix, :template_name_prefix) SENSITIVE = [] include Aws::Structure end |
#workload_name_prefix ⇒ String
An optional string added to the beginning of each workload name returned in the results.
5795 5796 5797 5798 5799 5800 5801 5802 5803 5804 5805 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 5795 class ListShareInvitationsInput < Struct.new( :workload_name_prefix, :lens_name_prefix, :share_resource_type, :next_token, :max_results, :profile_name_prefix, :template_name_prefix) SENSITIVE = [] include Aws::Structure end |