Class: Aws::WellArchitected::Types::ListTemplateSharesInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wellarchitected/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_results ⇒ Integer

The maximum number of results to return for this request.

Returns:

  • (Integer)


5873
5874
5875
5876
5877
5878
5879
5880
5881
# File 'lib/aws-sdk-wellarchitected/types.rb', line 5873

class ListTemplateSharesInput < Struct.new(
  :template_arn,
  :shared_with_prefix,
  :next_token,
  :max_results,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The token to use to retrieve the next set of results.

Returns:

  • (String)


5873
5874
5875
5876
5877
5878
5879
5880
5881
# File 'lib/aws-sdk-wellarchitected/types.rb', line 5873

class ListTemplateSharesInput < Struct.new(
  :template_arn,
  :shared_with_prefix,
  :next_token,
  :max_results,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#shared_with_prefix ⇒ String

The Amazon Web Services account ID, organization ID, or organizational unit (OU) ID with which the profile is shared.

Returns:

  • (String)


5873
5874
5875
5876
5877
5878
5879
5880
5881
# File 'lib/aws-sdk-wellarchitected/types.rb', line 5873

class ListTemplateSharesInput < Struct.new(
  :template_arn,
  :shared_with_prefix,
  :next_token,
  :max_results,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The status of the share request.

Returns:

  • (String)


5873
5874
5875
5876
5877
5878
5879
5880
5881
# File 'lib/aws-sdk-wellarchitected/types.rb', line 5873

class ListTemplateSharesInput < Struct.new(
  :template_arn,
  :shared_with_prefix,
  :next_token,
  :max_results,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#template_arn ⇒ String

The review template ARN.

Returns:

  • (String)


5873
5874
5875
5876
5877
5878
5879
5880
5881
# File 'lib/aws-sdk-wellarchitected/types.rb', line 5873

class ListTemplateSharesInput < Struct.new(
  :template_arn,
  :shared_with_prefix,
  :next_token,
  :max_results,
  :status)
  SENSITIVE = []
  include Aws::Structure
end