Class: Aws::WellArchitected::Types::ListTemplateSharesOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::WellArchitected::Types::ListTemplateSharesOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wellarchitected/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to use to retrieve the next set of results.
-
#template_arn ⇒ String
The review template ARN.
-
#template_share_summaries ⇒ Array<Types::TemplateShareSummary>
A review template share summary return object.
Instance Attribute Details
#next_token ⇒ String
The token to use to retrieve the next set of results.
5897 5898 5899 5900 5901 5902 5903 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 5897 class ListTemplateSharesOutput < Struct.new( :template_arn, :template_share_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#template_arn ⇒ String
The review template ARN.
5897 5898 5899 5900 5901 5902 5903 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 5897 class ListTemplateSharesOutput < Struct.new( :template_arn, :template_share_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#template_share_summaries ⇒ Array<Types::TemplateShareSummary>
A review template share summary return object.
5897 5898 5899 5900 5901 5902 5903 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 5897 class ListTemplateSharesOutput < Struct.new( :template_arn, :template_share_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |