Class: Aws::WellArchitected::Types::PillarMetric
- Inherits:
-
Struct
- Object
- Struct
- Aws::WellArchitected::Types::PillarMetric
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wellarchitected/types.rb
Overview
A metric for a particular pillar in a lens.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#pillar_id ⇒ String
The ID used to identify a pillar, for example,
security. -
#questions ⇒ Array<Types::QuestionMetric>
The questions that have been identified as risks in the pillar.
-
#risk_counts ⇒ Hash<String,Integer>
A map from risk names to the count of how many questions have that rating.
Instance Attribute Details
#pillar_id ⇒ String
The ID used to identify a pillar, for example, security.
A pillar is identified by its PillarReviewSummary$PillarId.
6166 6167 6168 6169 6170 6171 6172 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 6166 class PillarMetric < Struct.new( :pillar_id, :risk_counts, :questions) SENSITIVE = [] include Aws::Structure end |
#questions ⇒ Array<Types::QuestionMetric>
The questions that have been identified as risks in the pillar.
6166 6167 6168 6169 6170 6171 6172 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 6166 class PillarMetric < Struct.new( :pillar_id, :risk_counts, :questions) SENSITIVE = [] include Aws::Structure end |
#risk_counts ⇒ Hash<String,Integer>
A map from risk names to the count of how many questions have that rating.
6166 6167 6168 6169 6170 6171 6172 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 6166 class PillarMetric < Struct.new( :pillar_id, :risk_counts, :questions) SENSITIVE = [] include Aws::Structure end |