Class: Aws::WellArchitected::Types::ProfileNotificationSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wellarchitected/types.rb

Overview

The profile notification summary.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#current_profile_version ⇒ String

The current profile version.

Returns:

  • (String)


6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
# File 'lib/aws-sdk-wellarchitected/types.rb', line 6335

class ProfileNotificationSummary < Struct.new(
  :current_profile_version,
  :latest_profile_version,
  :type,
  :profile_arn,
  :profile_name,
  :workload_id,
  :workload_name)
  SENSITIVE = []
  include Aws::Structure
end

#latest_profile_version ⇒ String

The latest profile version.

Returns:

  • (String)


6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
# File 'lib/aws-sdk-wellarchitected/types.rb', line 6335

class ProfileNotificationSummary < Struct.new(
  :current_profile_version,
  :latest_profile_version,
  :type,
  :profile_arn,
  :profile_name,
  :workload_id,
  :workload_name)
  SENSITIVE = []
  include Aws::Structure
end

#profile_arn ⇒ String

The profile ARN.

Returns:

  • (String)


6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
# File 'lib/aws-sdk-wellarchitected/types.rb', line 6335

class ProfileNotificationSummary < Struct.new(
  :current_profile_version,
  :latest_profile_version,
  :type,
  :profile_arn,
  :profile_name,
  :workload_id,
  :workload_name)
  SENSITIVE = []
  include Aws::Structure
end

#profile_name ⇒ String

The profile name.

Returns:

  • (String)


6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
# File 'lib/aws-sdk-wellarchitected/types.rb', line 6335

class ProfileNotificationSummary < Struct.new(
  :current_profile_version,
  :latest_profile_version,
  :type,
  :profile_arn,
  :profile_name,
  :workload_id,
  :workload_name)
  SENSITIVE = []
  include Aws::Structure
end

#type ⇒ String

Type of notification.

Returns:

  • (String)


6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
# File 'lib/aws-sdk-wellarchitected/types.rb', line 6335

class ProfileNotificationSummary < Struct.new(
  :current_profile_version,
  :latest_profile_version,
  :type,
  :profile_arn,
  :profile_name,
  :workload_id,
  :workload_name)
  SENSITIVE = []
  include Aws::Structure
end

#workload_id ⇒ String

The ID assigned to the workload. This ID is unique within an Amazon Web Services Region.

Returns:

  • (String)


6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
# File 'lib/aws-sdk-wellarchitected/types.rb', line 6335

class ProfileNotificationSummary < Struct.new(
  :current_profile_version,
  :latest_profile_version,
  :type,
  :profile_arn,
  :profile_name,
  :workload_id,
  :workload_name)
  SENSITIVE = []
  include Aws::Structure
end

#workload_name ⇒ String

The name of the workload.

The name must be unique within an account within an Amazon Web Services Region. Spaces and capitalization are ignored when checking for uniqueness.

Returns:

  • (String)


6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
# File 'lib/aws-sdk-wellarchitected/types.rb', line 6335

class ProfileNotificationSummary < Struct.new(
  :current_profile_version,
  :latest_profile_version,
  :type,
  :profile_arn,
  :profile_name,
  :workload_id,
  :workload_name)
  SENSITIVE = []
  include Aws::Structure
end