Class: Aws::WellArchitected::Types::ProfileShareSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::WellArchitected::Types::ProfileShareSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wellarchitected/types.rb
Overview
Summary of a profile share.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#share_id ⇒ String
The ID associated with the share.
-
#shared_with ⇒ String
The Amazon Web Services account ID, organization ID, or organizational unit (OU) ID with which the workload, lens, profile, or review template is shared.
-
#status ⇒ String
The status of the share request.
-
#status_message ⇒ String
Profile share invitation status message.
Instance Attribute Details
#share_id ⇒ String
The ID associated with the share.
6432 6433 6434 6435 6436 6437 6438 6439 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 6432 class ProfileShareSummary < Struct.new( :share_id, :shared_with, :status, :status_message) SENSITIVE = [] include Aws::Structure end |
#shared_with ⇒ String
The Amazon Web Services account ID, organization ID, or organizational unit (OU) ID with which the workload, lens, profile, or review template is shared.
6432 6433 6434 6435 6436 6437 6438 6439 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 6432 class ProfileShareSummary < Struct.new( :share_id, :shared_with, :status, :status_message) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the share request.
6432 6433 6434 6435 6436 6437 6438 6439 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 6432 class ProfileShareSummary < Struct.new( :share_id, :shared_with, :status, :status_message) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
Profile share invitation status message.
6432 6433 6434 6435 6436 6437 6438 6439 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 6432 class ProfileShareSummary < Struct.new( :share_id, :shared_with, :status, :status_message) SENSITIVE = [] include Aws::Structure end |