Class: Aws::WellArchitected::Types::ProfileSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wellarchitected/types.rb

Overview

Summary of a profile.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_at ⇒ Time

The date and time when the profile was created.

Returns:

  • (Time)


6473
6474
6475
6476
6477
6478
6479
6480
6481
6482
6483
# File 'lib/aws-sdk-wellarchitected/types.rb', line 6473

class ProfileSummary < Struct.new(
  :profile_arn,
  :profile_version,
  :profile_name,
  :profile_description,
  :owner,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#owner ⇒ String

An Amazon Web Services account ID.

Returns:

  • (String)


6473
6474
6475
6476
6477
6478
6479
6480
6481
6482
6483
# File 'lib/aws-sdk-wellarchitected/types.rb', line 6473

class ProfileSummary < Struct.new(
  :profile_arn,
  :profile_version,
  :profile_name,
  :profile_description,
  :owner,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#profile_arn ⇒ String

The profile ARN.

Returns:

  • (String)


6473
6474
6475
6476
6477
6478
6479
6480
6481
6482
6483
# File 'lib/aws-sdk-wellarchitected/types.rb', line 6473

class ProfileSummary < Struct.new(
  :profile_arn,
  :profile_version,
  :profile_name,
  :profile_description,
  :owner,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#profile_description ⇒ String

The profile description.

Returns:

  • (String)


6473
6474
6475
6476
6477
6478
6479
6480
6481
6482
6483
# File 'lib/aws-sdk-wellarchitected/types.rb', line 6473

class ProfileSummary < Struct.new(
  :profile_arn,
  :profile_version,
  :profile_name,
  :profile_description,
  :owner,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#profile_name ⇒ String

The profile name.

Returns:

  • (String)


6473
6474
6475
6476
6477
6478
6479
6480
6481
6482
6483
# File 'lib/aws-sdk-wellarchitected/types.rb', line 6473

class ProfileSummary < Struct.new(
  :profile_arn,
  :profile_version,
  :profile_name,
  :profile_description,
  :owner,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#profile_version ⇒ String

The profile version.

Returns:

  • (String)


6473
6474
6475
6476
6477
6478
6479
6480
6481
6482
6483
# File 'lib/aws-sdk-wellarchitected/types.rb', line 6473

class ProfileSummary < Struct.new(
  :profile_arn,
  :profile_version,
  :profile_name,
  :profile_description,
  :owner,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_at ⇒ Time

The date and time when the profile was last updated.

Returns:

  • (Time)


6473
6474
6475
6476
6477
6478
6479
6480
6481
6482
6483
# File 'lib/aws-sdk-wellarchitected/types.rb', line 6473

class ProfileSummary < Struct.new(
  :profile_arn,
  :profile_version,
  :profile_name,
  :profile_description,
  :owner,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end