Class: Aws::WellArchitected::Types::Progress

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wellarchitected/types.rb

Overview

Progress information for a recommendation generation process.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#completion_percentage ⇒ Float

The completion percentage of the generation process (0-100).

Returns:

  • (Float)


6593
6594
6595
6596
6597
6598
6599
# File 'lib/aws-sdk-wellarchitected/types.rb', line 6593

class Progress < Struct.new(
  :steps_completed,
  :total_steps,
  :completion_percentage)
  SENSITIVE = []
  include Aws::Structure
end

#steps_completed ⇒ Integer

The number of generation steps that have been completed.

Returns:

  • (Integer)


6593
6594
6595
6596
6597
6598
6599
# File 'lib/aws-sdk-wellarchitected/types.rb', line 6593

class Progress < Struct.new(
  :steps_completed,
  :total_steps,
  :completion_percentage)
  SENSITIVE = []
  include Aws::Structure
end

#total_steps ⇒ Integer

The total number of steps in the generation process.

Returns:

  • (Integer)


6593
6594
6595
6596
6597
6598
6599
# File 'lib/aws-sdk-wellarchitected/types.rb', line 6593

class Progress < Struct.new(
  :steps_completed,
  :total_steps,
  :completion_percentage)
  SENSITIVE = []
  include Aws::Structure
end