Class: Aws::WellArchitected::Types::RemediationStep
- Inherits:
-
Struct
- Object
- Struct
- Aws::WellArchitected::Types::RemediationStep
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wellarchitected/types.rb
Overview
One step within a remediation procedure.
Constant Summary collapse
- SENSITIVE =
[:title, :content]
Instance Attribute Summary collapse
-
#content ⇒ String
The content describing the step, which can include code examples and verification checklists.
-
#title ⇒ String
An optional short label for the step.
Instance Attribute Details
#content ⇒ String
The content describing the step, which can include code examples and verification checklists.
6709 6710 6711 6712 6713 6714 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 6709 class RemediationStep < Struct.new( :title, :content) SENSITIVE = [:title, :content] include Aws::Structure end |
#title ⇒ String
An optional short label for the step.
6709 6710 6711 6712 6713 6714 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 6709 class RemediationStep < Struct.new( :title, :content) SENSITIVE = [:title, :content] include Aws::Structure end |