Class: Aws::WellArchitected::Types::ReviewTemplateAnswerSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wellarchitected/types.rb

Overview

The summary of review template answers.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#answer_status ⇒ String

The status of whether or not this question has been answered.

Returns:

  • (String)


6996
6997
6998
6999
7000
7001
7002
7003
7004
7005
7006
7007
7008
7009
# File 'lib/aws-sdk-wellarchitected/types.rb', line 6996

class ReviewTemplateAnswerSummary < Struct.new(
  :question_id,
  :pillar_id,
  :question_title,
  :choices,
  :selected_choices,
  :choice_answer_summaries,
  :is_applicable,
  :answer_status,
  :reason,
  :question_type)
  SENSITIVE = []
  include Aws::Structure
end

#choice_answer_summaries ⇒ Array<Types::ChoiceAnswerSummary>

A list of selected choices to a question in the review template.

Returns:



6996
6997
6998
6999
7000
7001
7002
7003
7004
7005
7006
7007
7008
7009
# File 'lib/aws-sdk-wellarchitected/types.rb', line 6996

class ReviewTemplateAnswerSummary < Struct.new(
  :question_id,
  :pillar_id,
  :question_title,
  :choices,
  :selected_choices,
  :choice_answer_summaries,
  :is_applicable,
  :answer_status,
  :reason,
  :question_type)
  SENSITIVE = []
  include Aws::Structure
end

#choices ⇒ Array<Types::Choice>

List of choices available for a question.

Returns:



6996
6997
6998
6999
7000
7001
7002
7003
7004
7005
7006
7007
7008
7009
# File 'lib/aws-sdk-wellarchitected/types.rb', line 6996

class ReviewTemplateAnswerSummary < Struct.new(
  :question_id,
  :pillar_id,
  :question_title,
  :choices,
  :selected_choices,
  :choice_answer_summaries,
  :is_applicable,
  :answer_status,
  :reason,
  :question_type)
  SENSITIVE = []
  include Aws::Structure
end

#is_applicable ⇒ Boolean

Defines whether this question is applicable to a lens review.

Returns:

  • (Boolean)


6996
6997
6998
6999
7000
7001
7002
7003
7004
7005
7006
7007
7008
7009
# File 'lib/aws-sdk-wellarchitected/types.rb', line 6996

class ReviewTemplateAnswerSummary < Struct.new(
  :question_id,
  :pillar_id,
  :question_title,
  :choices,
  :selected_choices,
  :choice_answer_summaries,
  :is_applicable,
  :answer_status,
  :reason,
  :question_type)
  SENSITIVE = []
  include Aws::Structure
end

#pillar_id ⇒ String

The ID used to identify a pillar, for example, security.

A pillar is identified by its PillarReviewSummary$PillarId.

Returns:

  • (String)


6996
6997
6998
6999
7000
7001
7002
7003
7004
7005
7006
7007
7008
7009
# File 'lib/aws-sdk-wellarchitected/types.rb', line 6996

class ReviewTemplateAnswerSummary < Struct.new(
  :question_id,
  :pillar_id,
  :question_title,
  :choices,
  :selected_choices,
  :choice_answer_summaries,
  :is_applicable,
  :answer_status,
  :reason,
  :question_type)
  SENSITIVE = []
  include Aws::Structure
end

#question_id ⇒ String

The ID of the question.

Returns:

  • (String)


6996
6997
6998
6999
7000
7001
7002
7003
7004
7005
7006
7007
7008
7009
# File 'lib/aws-sdk-wellarchitected/types.rb', line 6996

class ReviewTemplateAnswerSummary < Struct.new(
  :question_id,
  :pillar_id,
  :question_title,
  :choices,
  :selected_choices,
  :choice_answer_summaries,
  :is_applicable,
  :answer_status,
  :reason,
  :question_type)
  SENSITIVE = []
  include Aws::Structure
end

#question_title ⇒ String

The title of the question.

Returns:

  • (String)


6996
6997
6998
6999
7000
7001
7002
7003
7004
7005
7006
7007
7008
7009
# File 'lib/aws-sdk-wellarchitected/types.rb', line 6996

class ReviewTemplateAnswerSummary < Struct.new(
  :question_id,
  :pillar_id,
  :question_title,
  :choices,
  :selected_choices,
  :choice_answer_summaries,
  :is_applicable,
  :answer_status,
  :reason,
  :question_type)
  SENSITIVE = []
  include Aws::Structure
end

#question_type ⇒ String

The type of question.

Returns:

  • (String)


6996
6997
6998
6999
7000
7001
7002
7003
7004
7005
7006
7007
7008
7009
# File 'lib/aws-sdk-wellarchitected/types.rb', line 6996

class ReviewTemplateAnswerSummary < Struct.new(
  :question_id,
  :pillar_id,
  :question_title,
  :choices,
  :selected_choices,
  :choice_answer_summaries,
  :is_applicable,
  :answer_status,
  :reason,
  :question_type)
  SENSITIVE = []
  include Aws::Structure
end

#reason ⇒ String

The reason why a choice is not-applicable to a question in the review template.

Returns:

  • (String)


6996
6997
6998
6999
7000
7001
7002
7003
7004
7005
7006
7007
7008
7009
# File 'lib/aws-sdk-wellarchitected/types.rb', line 6996

class ReviewTemplateAnswerSummary < Struct.new(
  :question_id,
  :pillar_id,
  :question_title,
  :choices,
  :selected_choices,
  :choice_answer_summaries,
  :is_applicable,
  :answer_status,
  :reason,
  :question_type)
  SENSITIVE = []
  include Aws::Structure
end

#selected_choices ⇒ Array<String>

List of selected choice IDs in a question answer.

The values entered replace the previously selected choices.

Returns:

  • (Array<String>)


6996
6997
6998
6999
7000
7001
7002
7003
7004
7005
7006
7007
7008
7009
# File 'lib/aws-sdk-wellarchitected/types.rb', line 6996

class ReviewTemplateAnswerSummary < Struct.new(
  :question_id,
  :pillar_id,
  :question_title,
  :choices,
  :selected_choices,
  :choice_answer_summaries,
  :is_applicable,
  :answer_status,
  :reason,
  :question_type)
  SENSITIVE = []
  include Aws::Structure
end