Class: Aws::WellArchitected::Types::ReviewTemplateSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::WellArchitected::Types::ReviewTemplateSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wellarchitected/types.rb
Overview
Summary of a review template.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
Description of the review template.
-
#lenses ⇒ Array<String>
Lenses associated with the review template.
-
#owner ⇒ String
An Amazon Web Services account ID.
-
#template_arn ⇒ String
The review template ARN.
-
#template_name ⇒ String
The name of the review template.
-
#update_status ⇒ String
The latest status of a review template.
-
#updated_at ⇒ Time
The date and time when the review template was last updated.
Instance Attribute Details
#description ⇒ String
Description of the review template.
7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 7153 class ReviewTemplateSummary < Struct.new( :description, :lenses, :owner, :updated_at, :template_arn, :template_name, :update_status) SENSITIVE = [] include Aws::Structure end |
#lenses ⇒ Array<String>
Lenses associated with the review template.
7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 7153 class ReviewTemplateSummary < Struct.new( :description, :lenses, :owner, :updated_at, :template_arn, :template_name, :update_status) SENSITIVE = [] include Aws::Structure end |
#owner ⇒ String
An Amazon Web Services account ID.
7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 7153 class ReviewTemplateSummary < Struct.new( :description, :lenses, :owner, :updated_at, :template_arn, :template_name, :update_status) SENSITIVE = [] include Aws::Structure end |
#template_arn ⇒ String
The review template ARN.
7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 7153 class ReviewTemplateSummary < Struct.new( :description, :lenses, :owner, :updated_at, :template_arn, :template_name, :update_status) SENSITIVE = [] include Aws::Structure end |
#template_name ⇒ String
The name of the review template.
7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 7153 class ReviewTemplateSummary < Struct.new( :description, :lenses, :owner, :updated_at, :template_arn, :template_name, :update_status) SENSITIVE = [] include Aws::Structure end |
#update_status ⇒ String
The latest status of a review template.
7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 7153 class ReviewTemplateSummary < Struct.new( :description, :lenses, :owner, :updated_at, :template_arn, :template_name, :update_status) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time when the review template was last updated.
7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 7153 class ReviewTemplateSummary < Struct.new( :description, :lenses, :owner, :updated_at, :template_arn, :template_name, :update_status) SENSITIVE = [] include Aws::Structure end |