Class: Aws::WellArchitected::Types::Scope

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wellarchitected/types.rb

Overview

Defines the scope for recommendation generation, specifying which pillars and goals to focus on.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#goal_ids ⇒ Array<String>

Specific goal IDs to focus on during recommendation generation.

Returns:

  • (Array<String>)


7203
7204
7205
7206
7207
7208
7209
# File 'lib/aws-sdk-wellarchitected/types.rb', line 7203

class Scope < Struct.new(
  :pillars,
  :goal_ids,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#items ⇒ Array<Types::PillarItem>

Optional per-pillar item filtering configuration.

Returns:



7203
7204
7205
7206
7207
7208
7209
# File 'lib/aws-sdk-wellarchitected/types.rb', line 7203

class Scope < Struct.new(
  :pillars,
  :goal_ids,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#pillars ⇒ Array<String>

The Well-Architected Tool Framework pillars to include in the generation scope.

Returns:

  • (Array<String>)


7203
7204
7205
7206
7207
7208
7209
# File 'lib/aws-sdk-wellarchitected/types.rb', line 7203

class Scope < Struct.new(
  :pillars,
  :goal_ids,
  :items)
  SENSITIVE = []
  include Aws::Structure
end