Class: Aws::WellArchitected::Types::UpdateAgentGoalRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wellarchitected/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:title, :description]

Instance Attribute Summary collapse

Instance Attribute Details

#client_token ⇒ String

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


7736
7737
7738
7739
7740
7741
7742
7743
7744
7745
# File 'lib/aws-sdk-wellarchitected/types.rb', line 7736

class UpdateAgentGoalRequest < Struct.new(
  :client_token,
  :profile_arn,
  :id,
  :pillars,
  :title,
  :description)
  SENSITIVE = [:title, :description]
  include Aws::Structure
end

#description ⇒ String

A description of the goal.

Returns:

  • (String)


7736
7737
7738
7739
7740
7741
7742
7743
7744
7745
# File 'lib/aws-sdk-wellarchitected/types.rb', line 7736

class UpdateAgentGoalRequest < Struct.new(
  :client_token,
  :profile_arn,
  :id,
  :pillars,
  :title,
  :description)
  SENSITIVE = [:title, :description]
  include Aws::Structure
end

#id ⇒ String

The unique identifier of the goal to update.

Returns:

  • (String)


7736
7737
7738
7739
7740
7741
7742
7743
7744
7745
# File 'lib/aws-sdk-wellarchitected/types.rb', line 7736

class UpdateAgentGoalRequest < Struct.new(
  :client_token,
  :profile_arn,
  :id,
  :pillars,
  :title,
  :description)
  SENSITIVE = [:title, :description]
  include Aws::Structure
end

#pillars ⇒ Array<String>

The updated pillars for the goal. Pillars define the optimization focus areas such as cost, performance, resilience, and operational excellence.

Returns:

  • (Array<String>)


7736
7737
7738
7739
7740
7741
7742
7743
7744
7745
# File 'lib/aws-sdk-wellarchitected/types.rb', line 7736

class UpdateAgentGoalRequest < Struct.new(
  :client_token,
  :profile_arn,
  :id,
  :pillars,
  :title,
  :description)
  SENSITIVE = [:title, :description]
  include Aws::Structure
end

#profile_arn ⇒ String

The Amazon Resource Name (ARN) of the profile containing the goal to update.

Returns:

  • (String)


7736
7737
7738
7739
7740
7741
7742
7743
7744
7745
# File 'lib/aws-sdk-wellarchitected/types.rb', line 7736

class UpdateAgentGoalRequest < Struct.new(
  :client_token,
  :profile_arn,
  :id,
  :pillars,
  :title,
  :description)
  SENSITIVE = [:title, :description]
  include Aws::Structure
end

#title ⇒ String

The updated title for the goal. Maximum length of 1000 characters.

Returns:

  • (String)


7736
7737
7738
7739
7740
7741
7742
7743
7744
7745
# File 'lib/aws-sdk-wellarchitected/types.rb', line 7736

class UpdateAgentGoalRequest < Struct.new(
  :client_token,
  :profile_arn,
  :id,
  :pillars,
  :title,
  :description)
  SENSITIVE = [:title, :description]
  include Aws::Structure
end