Class: Aws::WellArchitected::Types::UpdateAgentProfileRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wellarchitected/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:display_name, :description, :business_overview]

Instance Attribute Summary collapse

Instance Attribute Details

#aggregation_configuration ⇒ Array<Types::AggregationConfiguration>

The updated aggregation configuration.



7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
# File 'lib/aws-sdk-wellarchitected/types.rb', line 7801

class UpdateAgentProfileRequest < Struct.new(
  :client_token,
  :profile_arn,
  :display_name,
  :description,
  :execution_role_arn,
  :aggregation_configuration,
  :business_overview,
  :pillars,
  :deletion_protection)
  SENSITIVE = [:display_name, :description, :business_overview]
  include Aws::Structure
end

#business_overview ⇒ String

The updated business overview for the profile.

Returns:

  • (String)


7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
# File 'lib/aws-sdk-wellarchitected/types.rb', line 7801

class UpdateAgentProfileRequest < Struct.new(
  :client_token,
  :profile_arn,
  :display_name,
  :description,
  :execution_role_arn,
  :aggregation_configuration,
  :business_overview,
  :pillars,
  :deletion_protection)
  SENSITIVE = [:display_name, :description, :business_overview]
  include Aws::Structure
end

#client_token ⇒ String

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
# File 'lib/aws-sdk-wellarchitected/types.rb', line 7801

class UpdateAgentProfileRequest < Struct.new(
  :client_token,
  :profile_arn,
  :display_name,
  :description,
  :execution_role_arn,
  :aggregation_configuration,
  :business_overview,
  :pillars,
  :deletion_protection)
  SENSITIVE = [:display_name, :description, :business_overview]
  include Aws::Structure
end

#deletion_protection ⇒ Boolean

Indicates whether deletion protection is enabled for the profile.

Returns:

  • (Boolean)


7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
# File 'lib/aws-sdk-wellarchitected/types.rb', line 7801

class UpdateAgentProfileRequest < Struct.new(
  :client_token,
  :profile_arn,
  :display_name,
  :description,
  :execution_role_arn,
  :aggregation_configuration,
  :business_overview,
  :pillars,
  :deletion_protection)
  SENSITIVE = [:display_name, :description, :business_overview]
  include Aws::Structure
end

#description ⇒ String

The updated description of the profile.

Returns:

  • (String)


7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
# File 'lib/aws-sdk-wellarchitected/types.rb', line 7801

class UpdateAgentProfileRequest < Struct.new(
  :client_token,
  :profile_arn,
  :display_name,
  :description,
  :execution_role_arn,
  :aggregation_configuration,
  :business_overview,
  :pillars,
  :deletion_protection)
  SENSITIVE = [:display_name, :description, :business_overview]
  include Aws::Structure
end

#display_name ⇒ String

The updated display name of the profile.

Returns:

  • (String)


7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
# File 'lib/aws-sdk-wellarchitected/types.rb', line 7801

class UpdateAgentProfileRequest < Struct.new(
  :client_token,
  :profile_arn,
  :display_name,
  :description,
  :execution_role_arn,
  :aggregation_configuration,
  :business_overview,
  :pillars,
  :deletion_protection)
  SENSITIVE = [:display_name, :description, :business_overview]
  include Aws::Structure
end

#execution_role_arn ⇒ String

The updated ARN of the IAM execution role.

Returns:

  • (String)


7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
# File 'lib/aws-sdk-wellarchitected/types.rb', line 7801

class UpdateAgentProfileRequest < Struct.new(
  :client_token,
  :profile_arn,
  :display_name,
  :description,
  :execution_role_arn,
  :aggregation_configuration,
  :business_overview,
  :pillars,
  :deletion_protection)
  SENSITIVE = [:display_name, :description, :business_overview]
  include Aws::Structure
end

#pillars ⇒ Array<String>

The updated Well-Architected Tool Framework pillars for the profile.

Returns:

  • (Array<String>)


7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
# File 'lib/aws-sdk-wellarchitected/types.rb', line 7801

class UpdateAgentProfileRequest < Struct.new(
  :client_token,
  :profile_arn,
  :display_name,
  :description,
  :execution_role_arn,
  :aggregation_configuration,
  :business_overview,
  :pillars,
  :deletion_protection)
  SENSITIVE = [:display_name, :description, :business_overview]
  include Aws::Structure
end

#profile_arn ⇒ String

The Amazon Resource Name (ARN) of the profile to update.

Returns:

  • (String)


7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
# File 'lib/aws-sdk-wellarchitected/types.rb', line 7801

class UpdateAgentProfileRequest < Struct.new(
  :client_token,
  :profile_arn,
  :display_name,
  :description,
  :execution_role_arn,
  :aggregation_configuration,
  :business_overview,
  :pillars,
  :deletion_protection)
  SENSITIVE = [:display_name, :description, :business_overview]
  include Aws::Structure
end