Class: Aws::WellArchitected::Types::UpdateAnswerInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wellarchitected/types.rb

Overview

Input to update answer.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#choice_updates ⇒ Hash<String,Types::ChoiceUpdate>

A list of choices to update on a question in your workload. The String key corresponds to the choice ID to be updated.

Returns:



7992
7993
7994
7995
7996
7997
7998
7999
8000
8001
8002
8003
# File 'lib/aws-sdk-wellarchitected/types.rb', line 7992

class UpdateAnswerInput < Struct.new(
  :workload_id,
  :lens_alias,
  :question_id,
  :selected_choices,
  :choice_updates,
  :notes,
  :is_applicable,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end

#is_applicable ⇒ Boolean

Defines whether this question is applicable to a lens review.

Returns:

  • (Boolean)


7992
7993
7994
7995
7996
7997
7998
7999
8000
8001
8002
8003
# File 'lib/aws-sdk-wellarchitected/types.rb', line 7992

class UpdateAnswerInput < Struct.new(
  :workload_id,
  :lens_alias,
  :question_id,
  :selected_choices,
  :choice_updates,
  :notes,
  :is_applicable,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end

#lens_alias ⇒ String

The alias of the lens.

For Amazon Web Services official lenses, this is either the lens alias, such as serverless, or the lens ARN, such as arn:aws:wellarchitected:us-east-1::lens/serverless. Note that some operations (such as ExportLens and CreateLensShare) are not permitted on Amazon Web Services official lenses.

For custom lenses, this is the lens ARN, such as arn:aws:wellarchitected:us-west-2:123456789012:lens/0123456789abcdef01234567890abcdef.

Each lens is identified by its LensSummary$LensAlias.

Returns:

  • (String)


7992
7993
7994
7995
7996
7997
7998
7999
8000
8001
8002
8003
# File 'lib/aws-sdk-wellarchitected/types.rb', line 7992

class UpdateAnswerInput < Struct.new(
  :workload_id,
  :lens_alias,
  :question_id,
  :selected_choices,
  :choice_updates,
  :notes,
  :is_applicable,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end

#notes ⇒ String

The notes associated with the workload.

For a review template, these are the notes that will be associated with the workload when the template is applied.

Returns:

  • (String)


7992
7993
7994
7995
7996
7997
7998
7999
8000
8001
8002
8003
# File 'lib/aws-sdk-wellarchitected/types.rb', line 7992

class UpdateAnswerInput < Struct.new(
  :workload_id,
  :lens_alias,
  :question_id,
  :selected_choices,
  :choice_updates,
  :notes,
  :is_applicable,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end

#question_id ⇒ String

The ID of the question.

Returns:

  • (String)


7992
7993
7994
7995
7996
7997
7998
7999
8000
8001
8002
8003
# File 'lib/aws-sdk-wellarchitected/types.rb', line 7992

class UpdateAnswerInput < Struct.new(
  :workload_id,
  :lens_alias,
  :question_id,
  :selected_choices,
  :choice_updates,
  :notes,
  :is_applicable,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end

#reason ⇒ String

The reason why a question is not applicable to your workload.

Returns:

  • (String)


7992
7993
7994
7995
7996
7997
7998
7999
8000
8001
8002
8003
# File 'lib/aws-sdk-wellarchitected/types.rb', line 7992

class UpdateAnswerInput < Struct.new(
  :workload_id,
  :lens_alias,
  :question_id,
  :selected_choices,
  :choice_updates,
  :notes,
  :is_applicable,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end

#selected_choices ⇒ Array<String>

List of selected choice IDs in a question answer.

The values entered replace the previously selected choices.

Returns:

  • (Array<String>)


7992
7993
7994
7995
7996
7997
7998
7999
8000
8001
8002
8003
# File 'lib/aws-sdk-wellarchitected/types.rb', line 7992

class UpdateAnswerInput < Struct.new(
  :workload_id,
  :lens_alias,
  :question_id,
  :selected_choices,
  :choice_updates,
  :notes,
  :is_applicable,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end

#workload_id ⇒ String

The ID assigned to the workload. This ID is unique within an Amazon Web Services Region.

Returns:

  • (String)


7992
7993
7994
7995
7996
7997
7998
7999
8000
8001
8002
8003
# File 'lib/aws-sdk-wellarchitected/types.rb', line 7992

class UpdateAnswerInput < Struct.new(
  :workload_id,
  :lens_alias,
  :question_id,
  :selected_choices,
  :choice_updates,
  :notes,
  :is_applicable,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end