Class: Aws::WellArchitected::Types::UpdateReviewTemplateAnswerInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wellarchitected/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#choice_updates ⇒ Hash<String,Types::ChoiceUpdate>

A list of choices to be updated.

Returns:



8261
8262
8263
8264
8265
8266
8267
8268
8269
8270
8271
8272
# File 'lib/aws-sdk-wellarchitected/types.rb', line 8261

class UpdateReviewTemplateAnswerInput < Struct.new(
  :template_arn,
  :lens_alias,
  :question_id,
  :selected_choices,
  :choice_updates,
  :notes,
  :is_applicable,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end

#is_applicable ⇒ Boolean

Defines whether this question is applicable to a lens review.

Returns:

  • (Boolean)


8261
8262
8263
8264
8265
8266
8267
8268
8269
8270
8271
8272
# File 'lib/aws-sdk-wellarchitected/types.rb', line 8261

class UpdateReviewTemplateAnswerInput < Struct.new(
  :template_arn,
  :lens_alias,
  :question_id,
  :selected_choices,
  :choice_updates,
  :notes,
  :is_applicable,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end

#lens_alias ⇒ String

The alias of the lens.

For Amazon Web Services official lenses, this is either the lens alias, such as serverless, or the lens ARN, such as arn:aws:wellarchitected:us-east-1::lens/serverless. Note that some operations (such as ExportLens and CreateLensShare) are not permitted on Amazon Web Services official lenses.

For custom lenses, this is the lens ARN, such as arn:aws:wellarchitected:us-west-2:123456789012:lens/0123456789abcdef01234567890abcdef.

Each lens is identified by its LensSummary$LensAlias.

Returns:

  • (String)


8261
8262
8263
8264
8265
8266
8267
8268
8269
8270
8271
8272
# File 'lib/aws-sdk-wellarchitected/types.rb', line 8261

class UpdateReviewTemplateAnswerInput < Struct.new(
  :template_arn,
  :lens_alias,
  :question_id,
  :selected_choices,
  :choice_updates,
  :notes,
  :is_applicable,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end

#notes ⇒ String

The notes associated with the workload.

For a review template, these are the notes that will be associated with the workload when the template is applied.

Returns:

  • (String)


8261
8262
8263
8264
8265
8266
8267
8268
8269
8270
8271
8272
# File 'lib/aws-sdk-wellarchitected/types.rb', line 8261

class UpdateReviewTemplateAnswerInput < Struct.new(
  :template_arn,
  :lens_alias,
  :question_id,
  :selected_choices,
  :choice_updates,
  :notes,
  :is_applicable,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end

#question_id ⇒ String

The ID of the question.

Returns:

  • (String)


8261
8262
8263
8264
8265
8266
8267
8268
8269
8270
8271
8272
# File 'lib/aws-sdk-wellarchitected/types.rb', line 8261

class UpdateReviewTemplateAnswerInput < Struct.new(
  :template_arn,
  :lens_alias,
  :question_id,
  :selected_choices,
  :choice_updates,
  :notes,
  :is_applicable,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end

#reason ⇒ String

The update reason.

Returns:

  • (String)


8261
8262
8263
8264
8265
8266
8267
8268
8269
8270
8271
8272
# File 'lib/aws-sdk-wellarchitected/types.rb', line 8261

class UpdateReviewTemplateAnswerInput < Struct.new(
  :template_arn,
  :lens_alias,
  :question_id,
  :selected_choices,
  :choice_updates,
  :notes,
  :is_applicable,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end

#selected_choices ⇒ Array<String>

List of selected choice IDs in a question answer.

The values entered replace the previously selected choices.

Returns:

  • (Array<String>)


8261
8262
8263
8264
8265
8266
8267
8268
8269
8270
8271
8272
# File 'lib/aws-sdk-wellarchitected/types.rb', line 8261

class UpdateReviewTemplateAnswerInput < Struct.new(
  :template_arn,
  :lens_alias,
  :question_id,
  :selected_choices,
  :choice_updates,
  :notes,
  :is_applicable,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end

#template_arn ⇒ String

The review template ARN.

Returns:

  • (String)


8261
8262
8263
8264
8265
8266
8267
8268
8269
8270
8271
8272
# File 'lib/aws-sdk-wellarchitected/types.rb', line 8261

class UpdateReviewTemplateAnswerInput < Struct.new(
  :template_arn,
  :lens_alias,
  :question_id,
  :selected_choices,
  :choice_updates,
  :notes,
  :is_applicable,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end