Class: Aws::WellArchitected::Types::UpdateReviewTemplateInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wellarchitected/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#description ⇒ String

The review template description.

Returns:



8337
8338
8339
8340
8341
8342
8343
8344
8345
8346
# File 'lib/aws-sdk-wellarchitected/types.rb', line 8337

class UpdateReviewTemplateInput < Struct.new(
  :template_arn,
  :template_name,
  :description,
  :notes,
  :lenses_to_associate,
  :lenses_to_disassociate)
  SENSITIVE = []
  include Aws::Structure
end

#lenses_to_associate ⇒ Array<String>

A list of lens aliases or ARNs to apply to the review template.

Returns:



8337
8338
8339
8340
8341
8342
8343
8344
8345
8346
# File 'lib/aws-sdk-wellarchitected/types.rb', line 8337

class UpdateReviewTemplateInput < Struct.new(
  :template_arn,
  :template_name,
  :description,
  :notes,
  :lenses_to_associate,
  :lenses_to_disassociate)
  SENSITIVE = []
  include Aws::Structure
end

#lenses_to_disassociate ⇒ Array<String>

A list of lens aliases or ARNs to unapply to the review template. The wellarchitected lens cannot be unapplied.

Returns:



8337
8338
8339
8340
8341
8342
8343
8344
8345
8346
# File 'lib/aws-sdk-wellarchitected/types.rb', line 8337

class UpdateReviewTemplateInput < Struct.new(
  :template_arn,
  :template_name,
  :description,
  :notes,
  :lenses_to_associate,
  :lenses_to_disassociate)
  SENSITIVE = []
  include Aws::Structure
end

#notes ⇒ String

The notes associated with the workload.

For a review template, these are the notes that will be associated with the workload when the template is applied.

Returns:



8337
8338
8339
8340
8341
8342
8343
8344
8345
8346
# File 'lib/aws-sdk-wellarchitected/types.rb', line 8337

class UpdateReviewTemplateInput < Struct.new(
  :template_arn,
  :template_name,
  :description,
  :notes,
  :lenses_to_associate,
  :lenses_to_disassociate)
  SENSITIVE = []
  include Aws::Structure
end

#template_arn ⇒ String

The review template ARN.

Returns:



8337
8338
8339
8340
8341
8342
8343
8344
8345
8346
# File 'lib/aws-sdk-wellarchitected/types.rb', line 8337

class UpdateReviewTemplateInput < Struct.new(
  :template_arn,
  :template_name,
  :description,
  :notes,
  :lenses_to_associate,
  :lenses_to_disassociate)
  SENSITIVE = []
  include Aws::Structure
end

#template_name ⇒ String

The review template name.

Returns:



8337
8338
8339
8340
8341
8342
8343
8344
8345
8346
# File 'lib/aws-sdk-wellarchitected/types.rb', line 8337

class UpdateReviewTemplateInput < Struct.new(
  :template_arn,
  :template_name,
  :description,
  :notes,
  :lenses_to_associate,
  :lenses_to_disassociate)
  SENSITIVE = []
  include Aws::Structure
end