Class: Aws::WellArchitected::Types::UpdateWorkloadInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wellarchitected/types.rb

Overview

Input to update a workload.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_ids ⇒ Array<String>

The list of Amazon Web Services account IDs associated with the workload.

Returns:

  • (Array<String>)


8605
8606
8607
8608
8609
8610
8611
8612
8613
8614
8615
8616
8617
8618
8619
8620
8621
8622
8623
8624
8625
8626
# File 'lib/aws-sdk-wellarchitected/types.rb', line 8605

class UpdateWorkloadInput < Struct.new(
  :workload_id,
  :workload_name,
  :description,
  :environment,
  :account_ids,
  :aws_regions,
  :non_aws_regions,
  :pillar_priorities,
  :architectural_design,
  :review_owner,
  :is_review_owner_update_acknowledged,
  :industry_type,
  :industry,
  :notes,
  :improvement_status,
  :discovery_config,
  :applications,
  :jira_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#applications ⇒ Array<String>

List of AppRegistry application ARNs to associate to the workload.

Returns:

  • (Array<String>)


8605
8606
8607
8608
8609
8610
8611
8612
8613
8614
8615
8616
8617
8618
8619
8620
8621
8622
8623
8624
8625
8626
# File 'lib/aws-sdk-wellarchitected/types.rb', line 8605

class UpdateWorkloadInput < Struct.new(
  :workload_id,
  :workload_name,
  :description,
  :environment,
  :account_ids,
  :aws_regions,
  :non_aws_regions,
  :pillar_priorities,
  :architectural_design,
  :review_owner,
  :is_review_owner_update_acknowledged,
  :industry_type,
  :industry,
  :notes,
  :improvement_status,
  :discovery_config,
  :applications,
  :jira_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#architectural_design ⇒ String

The URL of the architectural design for the workload.

Returns:

  • (String)


8605
8606
8607
8608
8609
8610
8611
8612
8613
8614
8615
8616
8617
8618
8619
8620
8621
8622
8623
8624
8625
8626
# File 'lib/aws-sdk-wellarchitected/types.rb', line 8605

class UpdateWorkloadInput < Struct.new(
  :workload_id,
  :workload_name,
  :description,
  :environment,
  :account_ids,
  :aws_regions,
  :non_aws_regions,
  :pillar_priorities,
  :architectural_design,
  :review_owner,
  :is_review_owner_update_acknowledged,
  :industry_type,
  :industry,
  :notes,
  :improvement_status,
  :discovery_config,
  :applications,
  :jira_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#aws_regions ⇒ Array<String>

The list of Amazon Web Services Regions associated with the workload, for example, us-east-2, or ca-central-1.

Returns:

  • (Array<String>)


8605
8606
8607
8608
8609
8610
8611
8612
8613
8614
8615
8616
8617
8618
8619
8620
8621
8622
8623
8624
8625
8626
# File 'lib/aws-sdk-wellarchitected/types.rb', line 8605

class UpdateWorkloadInput < Struct.new(
  :workload_id,
  :workload_name,
  :description,
  :environment,
  :account_ids,
  :aws_regions,
  :non_aws_regions,
  :pillar_priorities,
  :architectural_design,
  :review_owner,
  :is_review_owner_update_acknowledged,
  :industry_type,
  :industry,
  :notes,
  :improvement_status,
  :discovery_config,
  :applications,
  :jira_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

The description for the workload.

Returns:

  • (String)


8605
8606
8607
8608
8609
8610
8611
8612
8613
8614
8615
8616
8617
8618
8619
8620
8621
8622
8623
8624
8625
8626
# File 'lib/aws-sdk-wellarchitected/types.rb', line 8605

class UpdateWorkloadInput < Struct.new(
  :workload_id,
  :workload_name,
  :description,
  :environment,
  :account_ids,
  :aws_regions,
  :non_aws_regions,
  :pillar_priorities,
  :architectural_design,
  :review_owner,
  :is_review_owner_update_acknowledged,
  :industry_type,
  :industry,
  :notes,
  :improvement_status,
  :discovery_config,
  :applications,
  :jira_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#discovery_config ⇒ Types::WorkloadDiscoveryConfig

Well-Architected discovery configuration settings to associate to the workload.



8605
8606
8607
8608
8609
8610
8611
8612
8613
8614
8615
8616
8617
8618
8619
8620
8621
8622
8623
8624
8625
8626
# File 'lib/aws-sdk-wellarchitected/types.rb', line 8605

class UpdateWorkloadInput < Struct.new(
  :workload_id,
  :workload_name,
  :description,
  :environment,
  :account_ids,
  :aws_regions,
  :non_aws_regions,
  :pillar_priorities,
  :architectural_design,
  :review_owner,
  :is_review_owner_update_acknowledged,
  :industry_type,
  :industry,
  :notes,
  :improvement_status,
  :discovery_config,
  :applications,
  :jira_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#environment ⇒ String

The environment for the workload.

Returns:

  • (String)


8605
8606
8607
8608
8609
8610
8611
8612
8613
8614
8615
8616
8617
8618
8619
8620
8621
8622
8623
8624
8625
8626
# File 'lib/aws-sdk-wellarchitected/types.rb', line 8605

class UpdateWorkloadInput < Struct.new(
  :workload_id,
  :workload_name,
  :description,
  :environment,
  :account_ids,
  :aws_regions,
  :non_aws_regions,
  :pillar_priorities,
  :architectural_design,
  :review_owner,
  :is_review_owner_update_acknowledged,
  :industry_type,
  :industry,
  :notes,
  :improvement_status,
  :discovery_config,
  :applications,
  :jira_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#improvement_status ⇒ String

The improvement status for a workload.

Returns:

  • (String)


8605
8606
8607
8608
8609
8610
8611
8612
8613
8614
8615
8616
8617
8618
8619
8620
8621
8622
8623
8624
8625
8626
# File 'lib/aws-sdk-wellarchitected/types.rb', line 8605

class UpdateWorkloadInput < Struct.new(
  :workload_id,
  :workload_name,
  :description,
  :environment,
  :account_ids,
  :aws_regions,
  :non_aws_regions,
  :pillar_priorities,
  :architectural_design,
  :review_owner,
  :is_review_owner_update_acknowledged,
  :industry_type,
  :industry,
  :notes,
  :improvement_status,
  :discovery_config,
  :applications,
  :jira_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#industry ⇒ String

The industry for the workload.

Returns:

  • (String)


8605
8606
8607
8608
8609
8610
8611
8612
8613
8614
8615
8616
8617
8618
8619
8620
8621
8622
8623
8624
8625
8626
# File 'lib/aws-sdk-wellarchitected/types.rb', line 8605

class UpdateWorkloadInput < Struct.new(
  :workload_id,
  :workload_name,
  :description,
  :environment,
  :account_ids,
  :aws_regions,
  :non_aws_regions,
  :pillar_priorities,
  :architectural_design,
  :review_owner,
  :is_review_owner_update_acknowledged,
  :industry_type,
  :industry,
  :notes,
  :improvement_status,
  :discovery_config,
  :applications,
  :jira_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#industry_type ⇒ String

The industry type for the workload.

If specified, must be one of the following:

  • Agriculture

  • Automobile

  • Defense

  • Design and Engineering

  • Digital Advertising

  • Education

  • Environmental Protection

  • Financial Services

  • Gaming

  • General Public Services

  • Healthcare

  • Hospitality

  • InfoTech

  • Justice and Public Safety

  • Life Sciences

  • Manufacturing

  • Media & Entertainment

  • Mining & Resources

  • Oil & Gas

  • Power & Utilities

  • Professional Services

  • Real Estate & Construction

  • Retail & Wholesale

  • Social Protection

  • Telecommunications

  • Travel, Transportation & Logistics

  • Other

Returns:

  • (String)


8605
8606
8607
8608
8609
8610
8611
8612
8613
8614
8615
8616
8617
8618
8619
8620
8621
8622
8623
8624
8625
8626
# File 'lib/aws-sdk-wellarchitected/types.rb', line 8605

class UpdateWorkloadInput < Struct.new(
  :workload_id,
  :workload_name,
  :description,
  :environment,
  :account_ids,
  :aws_regions,
  :non_aws_regions,
  :pillar_priorities,
  :architectural_design,
  :review_owner,
  :is_review_owner_update_acknowledged,
  :industry_type,
  :industry,
  :notes,
  :improvement_status,
  :discovery_config,
  :applications,
  :jira_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#is_review_owner_update_acknowledged ⇒ Boolean

Flag indicating whether the workload owner has acknowledged that the Review owner field is required.

If a Review owner is not added to the workload within 60 days of acknowledgement, access to the workload is restricted until an owner is added.

Returns:

  • (Boolean)


8605
8606
8607
8608
8609
8610
8611
8612
8613
8614
8615
8616
8617
8618
8619
8620
8621
8622
8623
8624
8625
8626
# File 'lib/aws-sdk-wellarchitected/types.rb', line 8605

class UpdateWorkloadInput < Struct.new(
  :workload_id,
  :workload_name,
  :description,
  :environment,
  :account_ids,
  :aws_regions,
  :non_aws_regions,
  :pillar_priorities,
  :architectural_design,
  :review_owner,
  :is_review_owner_update_acknowledged,
  :industry_type,
  :industry,
  :notes,
  :improvement_status,
  :discovery_config,
  :applications,
  :jira_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#jira_configuration ⇒ Types::WorkloadJiraConfigurationInput

Configuration of the Jira integration.



8605
8606
8607
8608
8609
8610
8611
8612
8613
8614
8615
8616
8617
8618
8619
8620
8621
8622
8623
8624
8625
8626
# File 'lib/aws-sdk-wellarchitected/types.rb', line 8605

class UpdateWorkloadInput < Struct.new(
  :workload_id,
  :workload_name,
  :description,
  :environment,
  :account_ids,
  :aws_regions,
  :non_aws_regions,
  :pillar_priorities,
  :architectural_design,
  :review_owner,
  :is_review_owner_update_acknowledged,
  :industry_type,
  :industry,
  :notes,
  :improvement_status,
  :discovery_config,
  :applications,
  :jira_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#non_aws_regions ⇒ Array<String>

The list of non-Amazon Web Services Regions associated with the workload.

Returns:

  • (Array<String>)


8605
8606
8607
8608
8609
8610
8611
8612
8613
8614
8615
8616
8617
8618
8619
8620
8621
8622
8623
8624
8625
8626
# File 'lib/aws-sdk-wellarchitected/types.rb', line 8605

class UpdateWorkloadInput < Struct.new(
  :workload_id,
  :workload_name,
  :description,
  :environment,
  :account_ids,
  :aws_regions,
  :non_aws_regions,
  :pillar_priorities,
  :architectural_design,
  :review_owner,
  :is_review_owner_update_acknowledged,
  :industry_type,
  :industry,
  :notes,
  :improvement_status,
  :discovery_config,
  :applications,
  :jira_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#notes ⇒ String

The notes associated with the workload.

For a review template, these are the notes that will be associated with the workload when the template is applied.

Returns:

  • (String)


8605
8606
8607
8608
8609
8610
8611
8612
8613
8614
8615
8616
8617
8618
8619
8620
8621
8622
8623
8624
8625
8626
# File 'lib/aws-sdk-wellarchitected/types.rb', line 8605

class UpdateWorkloadInput < Struct.new(
  :workload_id,
  :workload_name,
  :description,
  :environment,
  :account_ids,
  :aws_regions,
  :non_aws_regions,
  :pillar_priorities,
  :architectural_design,
  :review_owner,
  :is_review_owner_update_acknowledged,
  :industry_type,
  :industry,
  :notes,
  :improvement_status,
  :discovery_config,
  :applications,
  :jira_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#pillar_priorities ⇒ Array<String>

The priorities of the pillars, which are used to order items in the improvement plan. Each pillar is represented by its PillarReviewSummary$PillarId.

Returns:

  • (Array<String>)


8605
8606
8607
8608
8609
8610
8611
8612
8613
8614
8615
8616
8617
8618
8619
8620
8621
8622
8623
8624
8625
8626
# File 'lib/aws-sdk-wellarchitected/types.rb', line 8605

class UpdateWorkloadInput < Struct.new(
  :workload_id,
  :workload_name,
  :description,
  :environment,
  :account_ids,
  :aws_regions,
  :non_aws_regions,
  :pillar_priorities,
  :architectural_design,
  :review_owner,
  :is_review_owner_update_acknowledged,
  :industry_type,
  :industry,
  :notes,
  :improvement_status,
  :discovery_config,
  :applications,
  :jira_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#review_owner ⇒ String

The review owner of the workload. The name, email address, or identifier for the primary group or individual that owns the workload review process.

Returns:

  • (String)


8605
8606
8607
8608
8609
8610
8611
8612
8613
8614
8615
8616
8617
8618
8619
8620
8621
8622
8623
8624
8625
8626
# File 'lib/aws-sdk-wellarchitected/types.rb', line 8605

class UpdateWorkloadInput < Struct.new(
  :workload_id,
  :workload_name,
  :description,
  :environment,
  :account_ids,
  :aws_regions,
  :non_aws_regions,
  :pillar_priorities,
  :architectural_design,
  :review_owner,
  :is_review_owner_update_acknowledged,
  :industry_type,
  :industry,
  :notes,
  :improvement_status,
  :discovery_config,
  :applications,
  :jira_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#workload_id ⇒ String

The ID assigned to the workload. This ID is unique within an Amazon Web Services Region.

Returns:

  • (String)


8605
8606
8607
8608
8609
8610
8611
8612
8613
8614
8615
8616
8617
8618
8619
8620
8621
8622
8623
8624
8625
8626
# File 'lib/aws-sdk-wellarchitected/types.rb', line 8605

class UpdateWorkloadInput < Struct.new(
  :workload_id,
  :workload_name,
  :description,
  :environment,
  :account_ids,
  :aws_regions,
  :non_aws_regions,
  :pillar_priorities,
  :architectural_design,
  :review_owner,
  :is_review_owner_update_acknowledged,
  :industry_type,
  :industry,
  :notes,
  :improvement_status,
  :discovery_config,
  :applications,
  :jira_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#workload_name ⇒ String

The name of the workload.

The name must be unique within an account within an Amazon Web Services Region. Spaces and capitalization are ignored when checking for uniqueness.

Returns:

  • (String)


8605
8606
8607
8608
8609
8610
8611
8612
8613
8614
8615
8616
8617
8618
8619
8620
8621
8622
8623
8624
8625
8626
# File 'lib/aws-sdk-wellarchitected/types.rb', line 8605

class UpdateWorkloadInput < Struct.new(
  :workload_id,
  :workload_name,
  :description,
  :environment,
  :account_ids,
  :aws_regions,
  :non_aws_regions,
  :pillar_priorities,
  :architectural_design,
  :review_owner,
  :is_review_owner_update_acknowledged,
  :industry_type,
  :industry,
  :notes,
  :improvement_status,
  :discovery_config,
  :applications,
  :jira_configuration)
  SENSITIVE = []
  include Aws::Structure
end