Class: Aws::WellArchitected::Types::WorkloadShareSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::WellArchitected::Types::WorkloadShareSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wellarchitected/types.rb
Overview
A workload share summary return object.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#permission_type ⇒ String
Permission granted on a share request.
-
#share_id ⇒ String
The ID associated with the share.
-
#shared_with ⇒ String
The Amazon Web Services account ID, organization ID, or organizational unit (OU) ID with which the workload, lens, profile, or review template is shared.
-
#status ⇒ String
The status of the share request.
-
#status_message ⇒ String
Optional message to compliment the Status field.
Instance Attribute Details
#permission_type ⇒ String
Permission granted on a share request.
9278 9279 9280 9281 9282 9283 9284 9285 9286 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 9278 class WorkloadShareSummary < Struct.new( :share_id, :shared_with, :permission_type, :status, :status_message) SENSITIVE = [] include Aws::Structure end |
#share_id ⇒ String
The ID associated with the share.
9278 9279 9280 9281 9282 9283 9284 9285 9286 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 9278 class WorkloadShareSummary < Struct.new( :share_id, :shared_with, :permission_type, :status, :status_message) SENSITIVE = [] include Aws::Structure end |
#shared_with ⇒ String
The Amazon Web Services account ID, organization ID, or organizational unit (OU) ID with which the workload, lens, profile, or review template is shared.
9278 9279 9280 9281 9282 9283 9284 9285 9286 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 9278 class WorkloadShareSummary < Struct.new( :share_id, :shared_with, :permission_type, :status, :status_message) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the share request.
9278 9279 9280 9281 9282 9283 9284 9285 9286 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 9278 class WorkloadShareSummary < Struct.new( :share_id, :shared_with, :permission_type, :status, :status_message) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
Optional message to compliment the Status field.
9278 9279 9280 9281 9282 9283 9284 9285 9286 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 9278 class WorkloadShareSummary < Struct.new( :share_id, :shared_with, :permission_type, :status, :status_message) SENSITIVE = [] include Aws::Structure end |