Class: Aws::WellArchitected::Types::WorkloadSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::WellArchitected::Types::WorkloadSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wellarchitected/types.rb
Overview
A workload summary return object.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#improvement_status ⇒ String
The improvement status for a workload.
-
#lenses ⇒ Array<String>
The list of lenses associated with the workload.
-
#owner ⇒ String
An Amazon Web Services account ID.
-
#prioritized_risk_counts ⇒ Hash<String,Integer>
A map from risk names to the count of how many questions have that rating.
-
#profiles ⇒ Array<Types::WorkloadProfile>
Profile associated with a workload.
-
#risk_counts ⇒ Hash<String,Integer>
A map from risk names to the count of how many questions have that rating.
-
#updated_at ⇒ Time
The date and time when the workload was last updated.
-
#workload_arn ⇒ String
The ARN for the workload.
-
#workload_id ⇒ String
The ID assigned to the workload.
-
#workload_name ⇒ String
The name of the workload.
Instance Attribute Details
#improvement_status ⇒ String
The improvement status for a workload.
9356 9357 9358 9359 9360 9361 9362 9363 9364 9365 9366 9367 9368 9369 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 9356 class WorkloadSummary < Struct.new( :workload_id, :workload_arn, :workload_name, :owner, :updated_at, :lenses, :risk_counts, :improvement_status, :profiles, :prioritized_risk_counts) SENSITIVE = [] include Aws::Structure end |
#lenses ⇒ Array<String>
The list of lenses associated with the workload. Each lens is identified by its LensSummary$LensAlias.
If a review template that specifies lenses is applied to the workload, those lenses are applied to the workload in addition to these lenses.
9356 9357 9358 9359 9360 9361 9362 9363 9364 9365 9366 9367 9368 9369 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 9356 class WorkloadSummary < Struct.new( :workload_id, :workload_arn, :workload_name, :owner, :updated_at, :lenses, :risk_counts, :improvement_status, :profiles, :prioritized_risk_counts) SENSITIVE = [] include Aws::Structure end |
#owner ⇒ String
An Amazon Web Services account ID.
9356 9357 9358 9359 9360 9361 9362 9363 9364 9365 9366 9367 9368 9369 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 9356 class WorkloadSummary < Struct.new( :workload_id, :workload_arn, :workload_name, :owner, :updated_at, :lenses, :risk_counts, :improvement_status, :profiles, :prioritized_risk_counts) SENSITIVE = [] include Aws::Structure end |
#prioritized_risk_counts ⇒ Hash<String,Integer>
A map from risk names to the count of how many questions have that rating.
9356 9357 9358 9359 9360 9361 9362 9363 9364 9365 9366 9367 9368 9369 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 9356 class WorkloadSummary < Struct.new( :workload_id, :workload_arn, :workload_name, :owner, :updated_at, :lenses, :risk_counts, :improvement_status, :profiles, :prioritized_risk_counts) SENSITIVE = [] include Aws::Structure end |
#profiles ⇒ Array<Types::WorkloadProfile>
Profile associated with a workload.
9356 9357 9358 9359 9360 9361 9362 9363 9364 9365 9366 9367 9368 9369 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 9356 class WorkloadSummary < Struct.new( :workload_id, :workload_arn, :workload_name, :owner, :updated_at, :lenses, :risk_counts, :improvement_status, :profiles, :prioritized_risk_counts) SENSITIVE = [] include Aws::Structure end |
#risk_counts ⇒ Hash<String,Integer>
A map from risk names to the count of how many questions have that rating.
9356 9357 9358 9359 9360 9361 9362 9363 9364 9365 9366 9367 9368 9369 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 9356 class WorkloadSummary < Struct.new( :workload_id, :workload_arn, :workload_name, :owner, :updated_at, :lenses, :risk_counts, :improvement_status, :profiles, :prioritized_risk_counts) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time when the workload was last updated.
9356 9357 9358 9359 9360 9361 9362 9363 9364 9365 9366 9367 9368 9369 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 9356 class WorkloadSummary < Struct.new( :workload_id, :workload_arn, :workload_name, :owner, :updated_at, :lenses, :risk_counts, :improvement_status, :profiles, :prioritized_risk_counts) SENSITIVE = [] include Aws::Structure end |
#workload_arn ⇒ String
The ARN for the workload.
9356 9357 9358 9359 9360 9361 9362 9363 9364 9365 9366 9367 9368 9369 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 9356 class WorkloadSummary < Struct.new( :workload_id, :workload_arn, :workload_name, :owner, :updated_at, :lenses, :risk_counts, :improvement_status, :profiles, :prioritized_risk_counts) SENSITIVE = [] include Aws::Structure end |
#workload_id ⇒ String
The ID assigned to the workload. This ID is unique within an Amazon Web Services Region.
9356 9357 9358 9359 9360 9361 9362 9363 9364 9365 9366 9367 9368 9369 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 9356 class WorkloadSummary < Struct.new( :workload_id, :workload_arn, :workload_name, :owner, :updated_at, :lenses, :risk_counts, :improvement_status, :profiles, :prioritized_risk_counts) SENSITIVE = [] include Aws::Structure end |
#workload_name ⇒ String
The name of the workload.
The name must be unique within an account within an Amazon Web Services Region. Spaces and capitalization are ignored when checking for uniqueness.
9356 9357 9358 9359 9360 9361 9362 9363 9364 9365 9366 9367 9368 9369 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 9356 class WorkloadSummary < Struct.new( :workload_id, :workload_arn, :workload_name, :owner, :updated_at, :lenses, :risk_counts, :improvement_status, :profiles, :prioritized_risk_counts) SENSITIVE = [] include Aws::Structure end |