Class: Aws::WellArchitected::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::WellArchitected::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-wellarchitected/client.rb,
sig/client.rbs
Overview
An API client for WellArchitected. To construct a client, you need to configure a :region and :credentials.
client = Aws::WellArchitected::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateLensShareResponseSuccess, _CreateLensVersionResponseSuccess, _CreateMilestoneResponseSuccess, _CreateProfileResponseSuccess, _CreateProfileShareResponseSuccess, _CreateReviewTemplateResponseSuccess, _CreateTemplateShareResponseSuccess, _CreateWorkloadResponseSuccess, _CreateWorkloadShareResponseSuccess, _ExportLensResponseSuccess, _GetAnswerResponseSuccess, _GetConsolidatedReportResponseSuccess, _GetGlobalSettingsResponseSuccess, _GetLensResponseSuccess, _GetLensReviewReportResponseSuccess, _GetLensReviewResponseSuccess, _GetLensVersionDifferenceResponseSuccess, _GetMilestoneResponseSuccess, _GetProfileResponseSuccess, _GetProfileTemplateResponseSuccess, _GetReviewTemplateAnswerResponseSuccess, _GetReviewTemplateLensReviewResponseSuccess, _GetReviewTemplateResponseSuccess, _GetWorkloadResponseSuccess, _ImportLensResponseSuccess, _ListAnswersResponseSuccess, _ListCheckDetailsResponseSuccess, _ListCheckSummariesResponseSuccess, _ListLensReviewImprovementsResponseSuccess, _ListLensReviewsResponseSuccess, _ListLensSharesResponseSuccess, _ListLensesResponseSuccess, _ListMilestonesResponseSuccess, _ListNotificationsResponseSuccess, _ListProfileNotificationsResponseSuccess, _ListProfileSharesResponseSuccess, _ListProfilesResponseSuccess, _ListReviewTemplateAnswersResponseSuccess, _ListReviewTemplatesResponseSuccess, _ListShareInvitationsResponseSuccess, _ListTagsForResourceResponseSuccess, _ListTemplateSharesResponseSuccess, _ListWorkloadSharesResponseSuccess, _ListWorkloadsResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateAnswerResponseSuccess, _UpdateLensReviewResponseSuccess, _UpdateProfileResponseSuccess, _UpdateReviewTemplateAnswerResponseSuccess, _UpdateReviewTemplateLensReviewResponseSuccess, _UpdateReviewTemplateResponseSuccess, _UpdateShareInvitationResponseSuccess, _UpdateWorkloadResponseSuccess, _UpdateWorkloadShareResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_lenses(params = {}) ⇒ Struct
Associate a lens to a workload.
-
#associate_profiles(params = {}) ⇒ Struct
Associate a profile with a workload.
-
#create_lens_share(params = {}) ⇒ Types::CreateLensShareOutput
Create a lens share.
-
#create_lens_version(params = {}) ⇒ Types::CreateLensVersionOutput
Create a new lens version.
-
#create_milestone(params = {}) ⇒ Types::CreateMilestoneOutput
Create a milestone for an existing workload.
-
#create_profile(params = {}) ⇒ Types::CreateProfileOutput
Create a profile.
-
#create_profile_share(params = {}) ⇒ Types::CreateProfileShareOutput
Create a profile share.
-
#create_review_template(params = {}) ⇒ Types::CreateReviewTemplateOutput
Create a review template.
-
#create_template_share(params = {}) ⇒ Types::CreateTemplateShareOutput
Create a review template share.
-
#create_workload(params = {}) ⇒ Types::CreateWorkloadOutput
Create a new workload.
-
#create_workload_share(params = {}) ⇒ Types::CreateWorkloadShareOutput
Create a workload share.
-
#delete_lens(params = {}) ⇒ Struct
Delete an existing lens.
-
#delete_lens_share(params = {}) ⇒ Struct
Delete a lens share.
-
#delete_profile(params = {}) ⇒ Struct
Delete a profile.
-
#delete_profile_share(params = {}) ⇒ Struct
Delete a profile share.
-
#delete_review_template(params = {}) ⇒ Struct
Delete a review template.
-
#delete_template_share(params = {}) ⇒ Struct
Delete a review template share.
-
#delete_workload(params = {}) ⇒ Struct
Delete an existing workload.
-
#delete_workload_share(params = {}) ⇒ Struct
Delete a workload share.
-
#disassociate_lenses(params = {}) ⇒ Struct
Disassociate a lens from a workload.
-
#disassociate_profiles(params = {}) ⇒ Struct
Disassociate a profile from a workload.
-
#export_lens(params = {}) ⇒ Types::ExportLensOutput
Export an existing lens.
-
#get_answer(params = {}) ⇒ Types::GetAnswerOutput
Get the answer to a specific question in a workload review.
-
#get_consolidated_report(params = {}) ⇒ Types::GetConsolidatedReportOutput
Get a consolidated report of your workloads.
-
#get_global_settings(params = {}) ⇒ Types::GetGlobalSettingsOutput
Global settings for all workloads.
-
#get_lens(params = {}) ⇒ Types::GetLensOutput
Get an existing lens.
-
#get_lens_review(params = {}) ⇒ Types::GetLensReviewOutput
Get lens review.
-
#get_lens_review_report(params = {}) ⇒ Types::GetLensReviewReportOutput
Get lens review report.
-
#get_lens_version_difference(params = {}) ⇒ Types::GetLensVersionDifferenceOutput
Get lens version differences.
-
#get_milestone(params = {}) ⇒ Types::GetMilestoneOutput
Get a milestone for an existing workload.
-
#get_profile(params = {}) ⇒ Types::GetProfileOutput
Get profile information.
-
#get_profile_template(params = {}) ⇒ Types::GetProfileTemplateOutput
Get profile template.
-
#get_review_template(params = {}) ⇒ Types::GetReviewTemplateOutput
Get review template.
-
#get_review_template_answer(params = {}) ⇒ Types::GetReviewTemplateAnswerOutput
Get review template answer.
-
#get_review_template_lens_review(params = {}) ⇒ Types::GetReviewTemplateLensReviewOutput
Get a lens review associated with a review template.
-
#get_workload(params = {}) ⇒ Types::GetWorkloadOutput
Get an existing workload.
-
#import_lens(params = {}) ⇒ Types::ImportLensOutput
Import a new custom lens or update an existing custom lens.
-
#list_answers(params = {}) ⇒ Types::ListAnswersOutput
List of answers for a particular workload and lens.
-
#list_check_details(params = {}) ⇒ Types::ListCheckDetailsOutput
List of Trusted Advisor check details by account related to the workload.
-
#list_check_summaries(params = {}) ⇒ Types::ListCheckSummariesOutput
List of Trusted Advisor checks summarized for all accounts related to the workload.
-
#list_lens_review_improvements(params = {}) ⇒ Types::ListLensReviewImprovementsOutput
List the improvements of a particular lens review.
-
#list_lens_reviews(params = {}) ⇒ Types::ListLensReviewsOutput
List lens reviews for a particular workload.
-
#list_lens_shares(params = {}) ⇒ Types::ListLensSharesOutput
List the lens shares associated with the lens.
-
#list_lenses(params = {}) ⇒ Types::ListLensesOutput
List the available lenses.
-
#list_milestones(params = {}) ⇒ Types::ListMilestonesOutput
List all milestones for an existing workload.
-
#list_notifications(params = {}) ⇒ Types::ListNotificationsOutput
List lens notifications.
-
#list_profile_notifications(params = {}) ⇒ Types::ListProfileNotificationsOutput
List profile notifications.
-
#list_profile_shares(params = {}) ⇒ Types::ListProfileSharesOutput
List profile shares.
-
#list_profiles(params = {}) ⇒ Types::ListProfilesOutput
List profiles.
-
#list_review_template_answers(params = {}) ⇒ Types::ListReviewTemplateAnswersOutput
List the answers of a review template.
-
#list_review_templates(params = {}) ⇒ Types::ListReviewTemplatesOutput
List review templates.
-
#list_share_invitations(params = {}) ⇒ Types::ListShareInvitationsOutput
List the share invitations.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
List the tags for a resource.
-
#list_template_shares(params = {}) ⇒ Types::ListTemplateSharesOutput
List review template shares.
-
#list_workload_shares(params = {}) ⇒ Types::ListWorkloadSharesOutput
List the workload shares associated with the workload.
-
#list_workloads(params = {}) ⇒ Types::ListWorkloadsOutput
Paginated list of workloads.
-
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Deletes specified tags from a resource.
-
#update_answer(params = {}) ⇒ Types::UpdateAnswerOutput
Update the answer to a specific question in a workload review.
-
#update_global_settings(params = {}) ⇒ Struct
Update whether the Amazon Web Services account is opted into organization sharing and discovery integration features.
-
#update_integration(params = {}) ⇒ Struct
Update integration features.
-
#update_lens_review(params = {}) ⇒ Types::UpdateLensReviewOutput
Update lens review for a particular workload.
-
#update_profile(params = {}) ⇒ Types::UpdateProfileOutput
Update a profile.
-
#update_review_template(params = {}) ⇒ Types::UpdateReviewTemplateOutput
Update a review template.
-
#update_review_template_answer(params = {}) ⇒ Types::UpdateReviewTemplateAnswerOutput
Update a review template answer.
-
#update_review_template_lens_review(params = {}) ⇒ Types::UpdateReviewTemplateLensReviewOutput
Update a lens review associated with a review template.
-
#update_share_invitation(params = {}) ⇒ Types::UpdateShareInvitationOutput
Update a workload or custom lens share invitation.
-
#update_workload(params = {}) ⇒ Types::UpdateWorkloadOutput
Update an existing workload.
-
#update_workload_share(params = {}) ⇒ Types::UpdateWorkloadShareOutput
Update a workload share.
-
#upgrade_lens_review(params = {}) ⇒ Struct
Upgrade lens review for a particular workload.
-
#upgrade_profile_version(params = {}) ⇒ Struct
Upgrade a profile.
-
#upgrade_review_template_lens_review(params = {}) ⇒ Struct
Upgrade the lens review of a review template.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-wellarchitected/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5264 5265 5266 |
# File 'lib/aws-sdk-wellarchitected/client.rb', line 5264 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5267 5268 5269 |
# File 'lib/aws-sdk-wellarchitected/client.rb', line 5267 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#associate_lenses(params = {}) ⇒ Struct
Associate a lens to a workload.
Up to 10 lenses can be associated with a workload in a single API operation. A maximum of 20 lenses can be associated with a workload.
By accessing and/or applying custom lenses created by another Amazon Web Services user or account, you acknowledge that custom lenses created by other users and shared with you are Third Party Content as defined in the Amazon Web Services Customer Agreement.
82 |
# File 'sig/client.rbs', line 82
def associate_lenses: (
|
#associate_profiles(params = {}) ⇒ Struct
Associate a profile with a workload.
89 |
# File 'sig/client.rbs', line 89
def associate_profiles: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5237 5238 5239 5240 5241 5242 5243 5244 5245 5246 5247 5248 5249 5250 5251 5252 5253 |
# File 'lib/aws-sdk-wellarchitected/client.rb', line 5237 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::WellArchitected') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-wellarchitected' context[:gem_version] = '1.71.0' Seahorse::Client::Request.new(handlers, context) end |
#create_lens_share(params = {}) ⇒ Types::CreateLensShareOutput
Create a lens share.
The owner of a lens can share it with other Amazon Web Services accounts, users, an organization, and organizational units (OUs) in the same Amazon Web Services Region. Lenses provided by Amazon Web Services (Amazon Web Services Official Content) cannot be shared.
Shared access to a lens is not removed until the lens invitation is deleted.
If you share a lens with an organization or OU, all accounts in the organization or OU are granted access to the lens.
For more information, see Sharing a custom lens in the Well-Architected Tool User Guide.
By sharing your custom lenses with other Amazon Web Services accounts, you acknowledge that Amazon Web Services will make your custom lenses available to those other accounts. Those other accounts may continue to access and use your shared custom lenses even if you delete the custom lenses from your own Amazon Web Services account or terminate your Amazon Web Services account.
100 |
# File 'sig/client.rbs', line 100
def create_lens_share: (
|
#create_lens_version(params = {}) ⇒ Types::CreateLensVersionOutput
Create a new lens version.
A lens can have up to 100 versions.
Use this operation to publish a new lens version after you have
imported a lens. The LensAlias is used to identify the lens to be
published. The owner of a lens can share the lens with other Amazon
Web Services accounts and users in the same Amazon Web Services
Region. Only the owner of a lens can delete it.
113 |
# File 'sig/client.rbs', line 113
def create_lens_version: (
|
#create_milestone(params = {}) ⇒ Types::CreateMilestoneOutput
Create a milestone for an existing workload.
127 |
# File 'sig/client.rbs', line 127
def create_milestone: (
|
#create_profile(params = {}) ⇒ Types::CreateProfileOutput
Create a profile.
140 |
# File 'sig/client.rbs', line 140
def create_profile: (
|
#create_profile_share(params = {}) ⇒ Types::CreateProfileShareOutput
Create a profile share.
160 |
# File 'sig/client.rbs', line 160
def create_profile_share: (
|
#create_review_template(params = {}) ⇒ Types::CreateReviewTemplateOutput
Create a review template.
Do not include or gather personal identifiable information (PII) of end users or other identifiable individuals in or via your review templates. If your review template or those shared with you and used in your account do include or collect PII you are responsible for: ensuring that the included PII is processed in accordance with applicable law, providing adequate privacy notices, and obtaining necessary consents for processing such data.
172 |
# File 'sig/client.rbs', line 172
def create_review_template: (
|
#create_template_share(params = {}) ⇒ Types::CreateTemplateShareOutput
Create a review template share.
The owner of a review template can share it with other Amazon Web Services accounts, users, an organization, and organizational units (OUs) in the same Amazon Web Services Region.
Shared access to a review template is not removed until the review template share invitation is deleted.
If you share a review template with an organization or OU, all accounts in the organization or OU are granted access to the review template.
By sharing your review template with other Amazon Web Services accounts, you acknowledge that Amazon Web Services will make your review template available to those other accounts.
188 |
# File 'sig/client.rbs', line 188
def create_template_share: (
|
#create_workload(params = {}) ⇒ Types::CreateWorkloadOutput
Create a new workload.
The owner of a workload can share the workload with other Amazon Web Services accounts, users, an organization, and organizational units (OUs) in the same Amazon Web Services Region. Only the owner of a workload can delete it.
For more information, see Defining a Workload in the Well-Architected Tool User Guide.
Either AwsRegions, NonAwsRegions, or both must be specified when
creating a workload.
You also must specify ReviewOwner, even though the parameter is
listed as not being required in the following section.
When creating a workload using a review template, you must have the following IAM permissions:
-
wellarchitected:GetReviewTemplate -
wellarchitected:GetReviewTemplateAnswer -
wellarchitected:ListReviewTemplateAnswers -
wellarchitected:GetReviewTemplateLensReview
201 |
# File 'sig/client.rbs', line 201
def create_workload: (
|
#create_workload_share(params = {}) ⇒ Types::CreateWorkloadShareOutput
Create a workload share.
The owner of a workload can share it with other Amazon Web Services accounts and users in the same Amazon Web Services Region. Shared access to a workload is not removed until the workload invitation is deleted.
If you share a workload with an organization or OU, all accounts in the organization or OU are granted access to the workload.
For more information, see Sharing a workload in the Well-Architected Tool User Guide.
238 |
# File 'sig/client.rbs', line 238
def create_workload_share: (
|
#delete_lens(params = {}) ⇒ Struct
Delete an existing lens.
Only the owner of a lens can delete it. After the lens is deleted, Amazon Web Services accounts and users that you shared the lens with can continue to use it, but they will no longer be able to apply it to new workloads.
By sharing your custom lenses with other Amazon Web Services accounts, you acknowledge that Amazon Web Services will make your custom lenses available to those other accounts. Those other accounts may continue to access and use your shared custom lenses even if you delete the custom lenses from your own Amazon Web Services account or terminate your Amazon Web Services account.
247 |
# File 'sig/client.rbs', line 247
def delete_lens: (
|
#delete_lens_share(params = {}) ⇒ Struct
Delete a lens share.
After the lens share is deleted, Amazon Web Services accounts, users, organizations, and organizational units (OUs) that you shared the lens with can continue to use it, but they will no longer be able to apply it to new workloads.
By sharing your custom lenses with other Amazon Web Services accounts, you acknowledge that Amazon Web Services will make your custom lenses available to those other accounts. Those other accounts may continue to access and use your shared custom lenses even if you delete the custom lenses from your own Amazon Web Services account or terminate your Amazon Web Services account.
255 |
# File 'sig/client.rbs', line 255
def delete_lens_share: (
|
#delete_profile(params = {}) ⇒ Struct
Delete a profile.
By sharing your profile with other Amazon Web Services accounts, you acknowledge that Amazon Web Services will make your profile available to those other accounts. Those other accounts may continue to access and use your shared profile even if you delete the profile from your own Amazon Web Services account or terminate your Amazon Web Services account.
263 |
# File 'sig/client.rbs', line 263
def delete_profile: (
|
#delete_profile_share(params = {}) ⇒ Struct
Delete a profile share.
270 |
# File 'sig/client.rbs', line 270
def delete_profile_share: (
|
#delete_review_template(params = {}) ⇒ Struct
Delete a review template.
Only the owner of a review template can delete it.
After the review template is deleted, Amazon Web Services accounts, users, organizations, and organizational units (OUs) that you shared the review template with will no longer be able to apply it to new workloads.
278 |
# File 'sig/client.rbs', line 278
def delete_review_template: (
|
#delete_template_share(params = {}) ⇒ Struct
Delete a review template share.
After the review template share is deleted, Amazon Web Services accounts, users, organizations, and organizational units (OUs) that you shared the review template with will no longer be able to apply it to new workloads.
285 |
# File 'sig/client.rbs', line 285
def delete_template_share: (
|
#delete_workload(params = {}) ⇒ Struct
Delete an existing workload.
293 |
# File 'sig/client.rbs', line 293
def delete_workload: (
|
#delete_workload_share(params = {}) ⇒ Struct
Delete a workload share.
300 |
# File 'sig/client.rbs', line 300
def delete_workload_share: (
|
#disassociate_lenses(params = {}) ⇒ Struct
Disassociate a lens from a workload.
Up to 10 lenses can be disassociated from a workload in a single API operation.
wellarchitected) cannot be removed from a workload.
308 |
# File 'sig/client.rbs', line 308
def disassociate_lenses: (
|
#disassociate_profiles(params = {}) ⇒ Struct
Disassociate a profile from a workload.
315 |
# File 'sig/client.rbs', line 315
def disassociate_profiles: (
|
#export_lens(params = {}) ⇒ Types::ExportLensOutput
Export an existing lens.
Only the owner of a lens can export it. Lenses provided by Amazon Web Services (Amazon Web Services Official Content) cannot be exported.
Lenses are defined in JSON. For more information, see JSON format specification in the Well-Architected Tool User Guide.
Do not include or gather personal identifiable information (PII) of end users or other identifiable individuals in or via your custom lenses. If your custom lens or those shared with you and used in your account do include or collect PII you are responsible for: ensuring that the included PII is processed in accordance with applicable law, providing adequate privacy notices, and obtaining necessary consents for processing such data.
326 |
# File 'sig/client.rbs', line 326
def export_lens: (
|
#get_answer(params = {}) ⇒ Types::GetAnswerOutput
Get the answer to a specific question in a workload review.
341 |
# File 'sig/client.rbs', line 341
def get_answer: (
|
#get_consolidated_report(params = {}) ⇒ Types::GetConsolidatedReportOutput
Get a consolidated report of your workloads.
You can optionally choose to include workloads that have been shared with you.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
356 |
# File 'sig/client.rbs', line 356
def get_consolidated_report: (
|
#get_global_settings(params = {}) ⇒ Types::GetGlobalSettingsOutput
Global settings for all workloads.
371 372 |
# File 'sig/client.rbs', line 371
def get_global_settings: () -> _GetGlobalSettingsResponseSuccess
| (?Hash[Symbol, untyped] params, ?Hash[Symbol, untyped] options) -> _GetGlobalSettingsResponseSuccess
|
#get_lens(params = {}) ⇒ Types::GetLensOutput
Get an existing lens.
379 |
# File 'sig/client.rbs', line 379
def get_lens: (
|
#get_lens_review(params = {}) ⇒ Types::GetLensReviewOutput
Get lens review.
392 |
# File 'sig/client.rbs', line 392
def get_lens_review: (
|
#get_lens_review_report(params = {}) ⇒ Types::GetLensReviewReportOutput
Get lens review report.
406 |
# File 'sig/client.rbs', line 406
def get_lens_review_report: (
|
#get_lens_version_difference(params = {}) ⇒ Types::GetLensVersionDifferenceOutput
Get lens version differences.
423 |
# File 'sig/client.rbs', line 423
def get_lens_version_difference: (
|
#get_milestone(params = {}) ⇒ Types::GetMilestoneOutput
Get a milestone for an existing workload.
436 |
# File 'sig/client.rbs', line 436
def get_milestone: (
|
#get_profile(params = {}) ⇒ Types::GetProfileOutput
Get profile information.
447 |
# File 'sig/client.rbs', line 447
def get_profile: (
|
#get_profile_template(params = {}) ⇒ Types::GetProfileTemplateOutput
Get profile template.
458 |
# File 'sig/client.rbs', line 458
def get_profile_template: (
|
#get_review_template(params = {}) ⇒ Types::GetReviewTemplateOutput
Get review template.
467 |
# File 'sig/client.rbs', line 467
def get_review_template: (
|
#get_review_template_answer(params = {}) ⇒ Types::GetReviewTemplateAnswerOutput
Get review template answer.
479 |
# File 'sig/client.rbs', line 479
def get_review_template_answer: (
|
#get_review_template_lens_review(params = {}) ⇒ Types::GetReviewTemplateLensReviewOutput
Get a lens review associated with a review template.
492 |
# File 'sig/client.rbs', line 492
def get_review_template_lens_review: (
|
#get_workload(params = {}) ⇒ Types::GetWorkloadOutput
Get an existing workload.
503 |
# File 'sig/client.rbs', line 503
def get_workload: (
|
#import_lens(params = {}) ⇒ Types::ImportLensOutput
Import a new custom lens or update an existing custom lens.
To update an existing custom lens, specify its ARN as the LensAlias.
If no ARN is specified, a new custom lens is created.
The new or updated lens will have a status of DRAFT. The lens cannot
be applied to workloads or shared with other Amazon Web Services
accounts until it's published with CreateLensVersion.
Lenses are defined in JSON. For more information, see JSON format specification in the Well-Architected Tool User Guide.
A custom lens cannot exceed 500 KB in size.
Do not include or gather personal identifiable information (PII) of end users or other identifiable individuals in or via your custom lenses. If your custom lens or those shared with you and used in your account do include or collect PII you are responsible for: ensuring that the included PII is processed in accordance with applicable law, providing adequate privacy notices, and obtaining necessary consents for processing such data.
514 |
# File 'sig/client.rbs', line 514
def import_lens: (
|
#list_answers(params = {}) ⇒ Types::ListAnswersOutput
List of answers for a particular workload and lens.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
532 |
# File 'sig/client.rbs', line 532
def list_answers: (
|
#list_check_details(params = {}) ⇒ Types::ListCheckDetailsOutput
List of Trusted Advisor check details by account related to the workload.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
549 |
# File 'sig/client.rbs', line 549
def list_check_details: (
|
#list_check_summaries(params = {}) ⇒ Types::ListCheckSummariesOutput
List of Trusted Advisor checks summarized for all accounts related to the workload.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
566 |
# File 'sig/client.rbs', line 566
def list_check_summaries: (
|
#list_lens_review_improvements(params = {}) ⇒ Types::ListLensReviewImprovementsOutput
List the improvements of a particular lens review.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
587 |
# File 'sig/client.rbs', line 587
def list_lens_review_improvements: (
|
#list_lens_reviews(params = {}) ⇒ Types::ListLensReviewsOutput
List lens reviews for a particular workload.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
606 |
# File 'sig/client.rbs', line 606
def list_lens_reviews: (
|
#list_lens_shares(params = {}) ⇒ Types::ListLensSharesOutput
List the lens shares associated with the lens.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
620 |
# File 'sig/client.rbs', line 620
def list_lens_shares: (
|
#list_lenses(params = {}) ⇒ Types::ListLensesOutput
List the available lenses.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
635 |
# File 'sig/client.rbs', line 635
def list_lenses: (
|
#list_milestones(params = {}) ⇒ Types::ListMilestonesOutput
List all milestones for an existing workload.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
651 |
# File 'sig/client.rbs', line 651
def list_milestones: (
|
#list_notifications(params = {}) ⇒ Types::ListNotificationsOutput
List lens notifications.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
664 |
# File 'sig/client.rbs', line 664
def list_notifications: (
|
#list_profile_notifications(params = {}) ⇒ Types::ListProfileNotificationsOutput
List profile notifications.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
678 |
# File 'sig/client.rbs', line 678
def list_profile_notifications: (
|
#list_profile_shares(params = {}) ⇒ Types::ListProfileSharesOutput
List profile shares.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
691 |
# File 'sig/client.rbs', line 691
def list_profile_shares: (
|
#list_profiles(params = {}) ⇒ Types::ListProfilesOutput
List profiles.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
706 |
# File 'sig/client.rbs', line 706
def list_profiles: (
|
#list_review_template_answers(params = {}) ⇒ Types::ListReviewTemplateAnswersOutput
List the answers of a review template.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
722 |
# File 'sig/client.rbs', line 722
def list_review_template_answers: (
|
#list_review_templates(params = {}) ⇒ Types::ListReviewTemplatesOutput
List review templates.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
737 |
# File 'sig/client.rbs', line 737
def list_review_templates: (
|
#list_share_invitations(params = {}) ⇒ Types::ListShareInvitationsOutput
List the share invitations.
WorkloadNamePrefix, LensNamePrefix, ProfileNamePrefix, and
TemplateNamePrefix are mutually exclusive. Use the parameter that
matches your ShareResourceType.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
749 |
# File 'sig/client.rbs', line 749
def list_share_invitations: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
List the tags for a resource.
765 |
# File 'sig/client.rbs', line 765
def list_tags_for_resource: (
|
#list_template_shares(params = {}) ⇒ Types::ListTemplateSharesOutput
List review template shares.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
777 |
# File 'sig/client.rbs', line 777
def list_template_shares: (
|
#list_workload_shares(params = {}) ⇒ Types::ListWorkloadSharesOutput
List the workload shares associated with the workload.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
793 |
# File 'sig/client.rbs', line 793
def list_workload_shares: (
|
#list_workloads(params = {}) ⇒ Types::ListWorkloadsOutput
Paginated list of workloads.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
808 |
# File 'sig/client.rbs', line 808
def list_workloads: (
|
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to the specified resource.
819 |
# File 'sig/client.rbs', line 819
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Deletes specified tags from a resource.
To specify multiple tags, use separate tagKeys parameters, for example:
DELETE /tags/WorkloadArn?tagKeys=key1&tagKeys=key2
829 |
# File 'sig/client.rbs', line 829
def untag_resource: (
|
#update_answer(params = {}) ⇒ Types::UpdateAnswerOutput
Update the answer to a specific question in a workload review.
843 |
# File 'sig/client.rbs', line 843
def update_answer: (
|
#update_global_settings(params = {}) ⇒ Struct
Update whether the Amazon Web Services account is opted into organization sharing and discovery integration features.
860 |
# File 'sig/client.rbs', line 860
def update_global_settings: (
|
#update_integration(params = {}) ⇒ Struct
Update integration features.
873 |
# File 'sig/client.rbs', line 873
def update_integration: (
|
#update_lens_review(params = {}) ⇒ Types::UpdateLensReviewOutput
Update lens review for a particular workload.
886 |
# File 'sig/client.rbs', line 886
def update_lens_review: (
|
#update_profile(params = {}) ⇒ Types::UpdateProfileOutput
Update a profile.
907 |
# File 'sig/client.rbs', line 907
def update_profile: (
|
#update_review_template(params = {}) ⇒ Types::UpdateReviewTemplateOutput
Update a review template.
924 |
# File 'sig/client.rbs', line 924
def update_review_template: (
|
#update_review_template_answer(params = {}) ⇒ Types::UpdateReviewTemplateAnswerOutput
Update a review template answer.
941 |
# File 'sig/client.rbs', line 941
def update_review_template_answer: (
|
#update_review_template_lens_review(params = {}) ⇒ Types::UpdateReviewTemplateLensReviewOutput
Update a lens review associated with a review template.
963 |
# File 'sig/client.rbs', line 963
def update_review_template_lens_review: (
|
#update_share_invitation(params = {}) ⇒ Types::UpdateShareInvitationOutput
Update a workload or custom lens share invitation.
976 |
# File 'sig/client.rbs', line 976
def update_share_invitation: (
|
#update_workload(params = {}) ⇒ Types::UpdateWorkloadOutput
Update an existing workload.
987 |
# File 'sig/client.rbs', line 987
def update_workload: (
|
#update_workload_share(params = {}) ⇒ Types::UpdateWorkloadShareOutput
Update a workload share.
1022 |
# File 'sig/client.rbs', line 1022
def update_workload_share: (
|
#upgrade_lens_review(params = {}) ⇒ Struct
Upgrade lens review for a particular workload.
1030 |
# File 'sig/client.rbs', line 1030
def upgrade_lens_review: (
|
#upgrade_profile_version(params = {}) ⇒ Struct
Upgrade a profile.
1039 |
# File 'sig/client.rbs', line 1039
def upgrade_profile_version: (
|
#upgrade_review_template_lens_review(params = {}) ⇒ Struct
Upgrade the lens review of a review template.
1048 |
# File 'sig/client.rbs', line 1048
def upgrade_review_template_lens_review: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5257 5258 5259 |
# File 'lib/aws-sdk-wellarchitected/client.rb', line 5257 def waiter_names [] end |