Class: Aws::WellArchitected::Types::ConsolidatedReportMetric
- Inherits:
-
Struct
- Object
- Struct
- Aws::WellArchitected::Types::ConsolidatedReportMetric
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wellarchitected/types.rb
Overview
A metric that contributes to the consolidated report.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#lenses ⇒ Array<Types::LensMetric>
The metrics for the lenses in the workload.
-
#lenses_applied_count ⇒ Integer
The total number of lenses applied to the workload.
-
#metric_type ⇒ String
The metric type of a metric in the consolidated report.
-
#risk_counts ⇒ Hash<String,Integer>
A map from risk names to the count of how many questions have that rating.
-
#updated_at ⇒ Time
The date and time when the consolidated report metric was last updated.
-
#workload_arn ⇒ String
The ARN for the workload.
-
#workload_id ⇒ String
The ID assigned to the workload.
-
#workload_name ⇒ String
The name of the workload.
Instance Attribute Details
#lenses ⇒ Array<Types::LensMetric>
The metrics for the lenses in the workload.
1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 1154 class ConsolidatedReportMetric < Struct.new( :metric_type, :risk_counts, :workload_id, :workload_name, :workload_arn, :updated_at, :lenses, :lenses_applied_count) SENSITIVE = [] include Aws::Structure end |
#lenses_applied_count ⇒ Integer
The total number of lenses applied to the workload.
1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 1154 class ConsolidatedReportMetric < Struct.new( :metric_type, :risk_counts, :workload_id, :workload_name, :workload_arn, :updated_at, :lenses, :lenses_applied_count) SENSITIVE = [] include Aws::Structure end |
#metric_type ⇒ String
The metric type of a metric in the consolidated report. Currently only WORKLOAD metric types are supported.
1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 1154 class ConsolidatedReportMetric < Struct.new( :metric_type, :risk_counts, :workload_id, :workload_name, :workload_arn, :updated_at, :lenses, :lenses_applied_count) SENSITIVE = [] include Aws::Structure end |
#risk_counts ⇒ Hash<String,Integer>
A map from risk names to the count of how many questions have that rating.
1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 1154 class ConsolidatedReportMetric < Struct.new( :metric_type, :risk_counts, :workload_id, :workload_name, :workload_arn, :updated_at, :lenses, :lenses_applied_count) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time when the consolidated report metric was last updated.
1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 1154 class ConsolidatedReportMetric < Struct.new( :metric_type, :risk_counts, :workload_id, :workload_name, :workload_arn, :updated_at, :lenses, :lenses_applied_count) SENSITIVE = [] include Aws::Structure end |
#workload_arn ⇒ String
The ARN for the workload.
1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 1154 class ConsolidatedReportMetric < Struct.new( :metric_type, :risk_counts, :workload_id, :workload_name, :workload_arn, :updated_at, :lenses, :lenses_applied_count) SENSITIVE = [] include Aws::Structure end |
#workload_id ⇒ String
The ID assigned to the workload. This ID is unique within an Amazon Web Services Region.
1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 1154 class ConsolidatedReportMetric < Struct.new( :metric_type, :risk_counts, :workload_id, :workload_name, :workload_arn, :updated_at, :lenses, :lenses_applied_count) SENSITIVE = [] include Aws::Structure end |
#workload_name ⇒ String
The name of the workload.
The name must be unique within an account within an Amazon Web Services Region. Spaces and capitalization are ignored when checking for uniqueness.
1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 1154 class ConsolidatedReportMetric < Struct.new( :metric_type, :risk_counts, :workload_id, :workload_name, :workload_arn, :updated_at, :lenses, :lenses_applied_count) SENSITIVE = [] include Aws::Structure end |