Class: Aws::WellArchitected::Types::CreateAgentContextRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WellArchitected::Types::CreateAgentContextRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wellarchitected/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:title]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#content ⇒ Types::ContextContent
The typed content of the context.
-
#context_type ⇒ String
The type of the context.
-
#profile_arn ⇒ String
The Amazon Resource Name (ARN) of the profile to associate the context with.
-
#title ⇒ String
The title of the context.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
A suitable default value is auto-generated. You should normally not need to pass this option.
1352 1353 1354 1355 1356 1357 1358 1359 1360 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 1352 class CreateAgentContextRequest < Struct.new( :client_token, :profile_arn, :title, :context_type, :content) SENSITIVE = [:title] include Aws::Structure end |
#content ⇒ Types::ContextContent
The typed content of the context. The structure contains application-specific fields such as account IDs, Regions, services, and resource types.
1352 1353 1354 1355 1356 1357 1358 1359 1360 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 1352 class CreateAgentContextRequest < Struct.new( :client_token, :profile_arn, :title, :context_type, :content) SENSITIVE = [:title] include Aws::Structure end |
#context_type ⇒ String
The type of the context.
1352 1353 1354 1355 1356 1357 1358 1359 1360 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 1352 class CreateAgentContextRequest < Struct.new( :client_token, :profile_arn, :title, :context_type, :content) SENSITIVE = [:title] include Aws::Structure end |
#profile_arn ⇒ String
The Amazon Resource Name (ARN) of the profile to associate the context with.
1352 1353 1354 1355 1356 1357 1358 1359 1360 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 1352 class CreateAgentContextRequest < Struct.new( :client_token, :profile_arn, :title, :context_type, :content) SENSITIVE = [:title] include Aws::Structure end |
#title ⇒ String
The title of the context.
1352 1353 1354 1355 1356 1357 1358 1359 1360 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 1352 class CreateAgentContextRequest < Struct.new( :client_token, :profile_arn, :title, :context_type, :content) SENSITIVE = [:title] include Aws::Structure end |