Class: Aws::WellArchitected::Types::LensMetric
- Inherits:
-
Struct
- Object
- Struct
- Aws::WellArchitected::Types::LensMetric
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wellarchitected/types.rb
Overview
A metric for a particular lens in a workload.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#lens_arn ⇒ String
The lens ARN.
-
#pillars ⇒ Array<Types::PillarMetric>
The metrics for the pillars in a lens.
-
#risk_counts ⇒ Hash<String,Integer>
A map from risk names to the count of how many questions have that rating.
Instance Attribute Details
#lens_arn ⇒ String
The lens ARN.
4232 4233 4234 4235 4236 4237 4238 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 4232 class LensMetric < Struct.new( :lens_arn, :pillars, :risk_counts) SENSITIVE = [] include Aws::Structure end |
#pillars ⇒ Array<Types::PillarMetric>
The metrics for the pillars in a lens.
4232 4233 4234 4235 4236 4237 4238 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 4232 class LensMetric < Struct.new( :lens_arn, :pillars, :risk_counts) SENSITIVE = [] include Aws::Structure end |
#risk_counts ⇒ Hash<String,Integer>
A map from risk names to the count of how many questions have that rating.
4232 4233 4234 4235 4236 4237 4238 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 4232 class LensMetric < Struct.new( :lens_arn, :pillars, :risk_counts) SENSITIVE = [] include Aws::Structure end |