Class: Aws::WellArchitected::Types::LensReviewSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::WellArchitected::Types::LensReviewSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wellarchitected/types.rb
Overview
A lens review summary of a workload.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#lens_alias ⇒ String
The alias of the lens.
-
#lens_arn ⇒ String
The ARN for the lens.
-
#lens_name ⇒ String
The full name of the lens.
-
#lens_status ⇒ String
The status of the lens.
-
#lens_version ⇒ String
The version of the lens.
-
#prioritized_risk_counts ⇒ Hash<String,Integer>
A map from risk names to the count of how many questions have that rating.
-
#profiles ⇒ Array<Types::WorkloadProfile>
The profiles associated with the workload.
-
#risk_counts ⇒ Hash<String,Integer>
A map from risk names to the count of how many questions have that rating.
-
#updated_at ⇒ Time
The date and time when the lens review was last updated.
Instance Attribute Details
#lens_alias ⇒ String
The alias of the lens.
For Amazon Web Services official lenses, this is either the lens
alias, such as serverless, or the lens ARN, such as
arn:aws:wellarchitected:us-east-1::lens/serverless. Note that some
operations (such as ExportLens and CreateLensShare) are not
permitted on Amazon Web Services official lenses.
For custom lenses, this is the lens ARN, such as
arn:aws:wellarchitected:us-west-2:123456789012:lens/0123456789abcdef01234567890abcdef.
Each lens is identified by its LensSummary$LensAlias.
4423 4424 4425 4426 4427 4428 4429 4430 4431 4432 4433 4434 4435 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 4423 class LensReviewSummary < Struct.new( :lens_alias, :lens_arn, :lens_version, :lens_name, :lens_status, :updated_at, :risk_counts, :profiles, :prioritized_risk_counts) SENSITIVE = [] include Aws::Structure end |
#lens_arn ⇒ String
The ARN for the lens.
4423 4424 4425 4426 4427 4428 4429 4430 4431 4432 4433 4434 4435 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 4423 class LensReviewSummary < Struct.new( :lens_alias, :lens_arn, :lens_version, :lens_name, :lens_status, :updated_at, :risk_counts, :profiles, :prioritized_risk_counts) SENSITIVE = [] include Aws::Structure end |
#lens_name ⇒ String
The full name of the lens.
4423 4424 4425 4426 4427 4428 4429 4430 4431 4432 4433 4434 4435 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 4423 class LensReviewSummary < Struct.new( :lens_alias, :lens_arn, :lens_version, :lens_name, :lens_status, :updated_at, :risk_counts, :profiles, :prioritized_risk_counts) SENSITIVE = [] include Aws::Structure end |
#lens_status ⇒ String
The status of the lens.
4423 4424 4425 4426 4427 4428 4429 4430 4431 4432 4433 4434 4435 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 4423 class LensReviewSummary < Struct.new( :lens_alias, :lens_arn, :lens_version, :lens_name, :lens_status, :updated_at, :risk_counts, :profiles, :prioritized_risk_counts) SENSITIVE = [] include Aws::Structure end |
#lens_version ⇒ String
The version of the lens.
4423 4424 4425 4426 4427 4428 4429 4430 4431 4432 4433 4434 4435 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 4423 class LensReviewSummary < Struct.new( :lens_alias, :lens_arn, :lens_version, :lens_name, :lens_status, :updated_at, :risk_counts, :profiles, :prioritized_risk_counts) SENSITIVE = [] include Aws::Structure end |
#prioritized_risk_counts ⇒ Hash<String,Integer>
A map from risk names to the count of how many questions have that rating.
4423 4424 4425 4426 4427 4428 4429 4430 4431 4432 4433 4434 4435 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 4423 class LensReviewSummary < Struct.new( :lens_alias, :lens_arn, :lens_version, :lens_name, :lens_status, :updated_at, :risk_counts, :profiles, :prioritized_risk_counts) SENSITIVE = [] include Aws::Structure end |
#profiles ⇒ Array<Types::WorkloadProfile>
The profiles associated with the workload.
4423 4424 4425 4426 4427 4428 4429 4430 4431 4432 4433 4434 4435 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 4423 class LensReviewSummary < Struct.new( :lens_alias, :lens_arn, :lens_version, :lens_name, :lens_status, :updated_at, :risk_counts, :profiles, :prioritized_risk_counts) SENSITIVE = [] include Aws::Structure end |
#risk_counts ⇒ Hash<String,Integer>
A map from risk names to the count of how many questions have that rating.
4423 4424 4425 4426 4427 4428 4429 4430 4431 4432 4433 4434 4435 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 4423 class LensReviewSummary < Struct.new( :lens_alias, :lens_arn, :lens_version, :lens_name, :lens_status, :updated_at, :risk_counts, :profiles, :prioritized_risk_counts) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time when the lens review was last updated.
4423 4424 4425 4426 4427 4428 4429 4430 4431 4432 4433 4434 4435 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 4423 class LensReviewSummary < Struct.new( :lens_alias, :lens_arn, :lens_version, :lens_name, :lens_status, :updated_at, :risk_counts, :profiles, :prioritized_risk_counts) SENSITIVE = [] include Aws::Structure end |