Class: Aws::WellArchitected::Types::LensUpgradeSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::WellArchitected::Types::LensUpgradeSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wellarchitected/types.rb
Overview
Lens upgrade summary return object.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#current_lens_version ⇒ String
The current version of the lens.
-
#latest_lens_version ⇒ String
The latest version of the lens.
-
#lens_alias ⇒ String
The alias of the lens.
-
#lens_arn ⇒ String
The ARN for the lens.
-
#resource_arn ⇒ String
ResourceArnof the lens being upgraded. -
#resource_name ⇒ String
The name of the workload.
-
#workload_id ⇒ String
The ID assigned to the workload.
-
#workload_name ⇒ String
The name of the workload.
Instance Attribute Details
#current_lens_version ⇒ String
The current version of the lens.
4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 4605 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 4594 class LensUpgradeSummary < Struct.new( :workload_id, :workload_name, :lens_alias, :lens_arn, :current_lens_version, :latest_lens_version, :resource_arn, :resource_name) SENSITIVE = [] include Aws::Structure end |
#latest_lens_version ⇒ String
The latest version of the lens.
4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 4605 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 4594 class LensUpgradeSummary < Struct.new( :workload_id, :workload_name, :lens_alias, :lens_arn, :current_lens_version, :latest_lens_version, :resource_arn, :resource_name) SENSITIVE = [] include Aws::Structure end |
#lens_alias ⇒ String
The alias of the lens.
For Amazon Web Services official lenses, this is either the lens
alias, such as serverless, or the lens ARN, such as
arn:aws:wellarchitected:us-east-1::lens/serverless. Note that some
operations (such as ExportLens and CreateLensShare) are not
permitted on Amazon Web Services official lenses.
For custom lenses, this is the lens ARN, such as
arn:aws:wellarchitected:us-west-2:123456789012:lens/0123456789abcdef01234567890abcdef.
Each lens is identified by its LensSummary$LensAlias.
4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 4605 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 4594 class LensUpgradeSummary < Struct.new( :workload_id, :workload_name, :lens_alias, :lens_arn, :current_lens_version, :latest_lens_version, :resource_arn, :resource_name) SENSITIVE = [] include Aws::Structure end |
#lens_arn ⇒ String
The ARN for the lens.
4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 4605 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 4594 class LensUpgradeSummary < Struct.new( :workload_id, :workload_name, :lens_alias, :lens_arn, :current_lens_version, :latest_lens_version, :resource_arn, :resource_name) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
ResourceArn of the lens being upgraded
4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 4605 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 4594 class LensUpgradeSummary < Struct.new( :workload_id, :workload_name, :lens_alias, :lens_arn, :current_lens_version, :latest_lens_version, :resource_arn, :resource_name) SENSITIVE = [] include Aws::Structure end |
#resource_name ⇒ String
The name of the workload.
The name must be unique within an account within an Amazon Web Services Region. Spaces and capitalization are ignored when checking for uniqueness.
4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 4605 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 4594 class LensUpgradeSummary < Struct.new( :workload_id, :workload_name, :lens_alias, :lens_arn, :current_lens_version, :latest_lens_version, :resource_arn, :resource_name) SENSITIVE = [] include Aws::Structure end |
#workload_id ⇒ String
The ID assigned to the workload. This ID is unique within an Amazon Web Services Region.
4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 4605 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 4594 class LensUpgradeSummary < Struct.new( :workload_id, :workload_name, :lens_alias, :lens_arn, :current_lens_version, :latest_lens_version, :resource_arn, :resource_name) SENSITIVE = [] include Aws::Structure end |
#workload_name ⇒ String
The name of the workload.
The name must be unique within an account within an Amazon Web Services Region. Spaces and capitalization are ignored when checking for uniqueness.
4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 4605 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 4594 class LensUpgradeSummary < Struct.new( :workload_id, :workload_name, :lens_alias, :lens_arn, :current_lens_version, :latest_lens_version, :resource_arn, :resource_name) SENSITIVE = [] include Aws::Structure end |