Class: Aws::WellArchitected::Types::PillarItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::WellArchitected::Types::PillarItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wellarchitected/types.rb
Overview
Item configuration for a specific Well-Architected Tool Framework pillar.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ids ⇒ Array<String>
A list of item IDs to process for this pillar, such as best practice IDs, Amazon Web Services service names, or resource ARNs.
-
#pillar ⇒ String
The pillar this item configuration applies to.
Instance Attribute Details
#ids ⇒ Array<String>
A list of item IDs to process for this pillar, such as best practice IDs, Amazon Web Services service names, or resource ARNs.
6140 6141 6142 6143 6144 6145 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 6140 class PillarItem < Struct.new( :pillar, :ids) SENSITIVE = [] include Aws::Structure end |
#pillar ⇒ String
The pillar this item configuration applies to.
6140 6141 6142 6143 6144 6145 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 6140 class PillarItem < Struct.new( :pillar, :ids) SENSITIVE = [] include Aws::Structure end |