Class: Aws::WellArchitected::Types::UpdateAgentContextRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WellArchitected::Types::UpdateAgentContextRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wellarchitected/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:title]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#content ⇒ Types::ContextContent
The updated typed content of the context.
-
#id ⇒ String
The unique identifier of the context to update.
-
#profile_arn ⇒ String
The Amazon Resource Name (ARN) of the profile containing the context.
-
#title ⇒ String
The updated title of the context.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
A suitable default value is auto-generated. You should normally not need to pass this option.
7681 7682 7683 7684 7685 7686 7687 7688 7689 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 7681 class UpdateAgentContextRequest < Struct.new( :client_token, :profile_arn, :id, :title, :content) SENSITIVE = [:title] include Aws::Structure end |
#content ⇒ Types::ContextContent
The updated typed content of the context. The structure contains application-specific fields such as account IDs, Regions, services, and resource types.
7681 7682 7683 7684 7685 7686 7687 7688 7689 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 7681 class UpdateAgentContextRequest < Struct.new( :client_token, :profile_arn, :id, :title, :content) SENSITIVE = [:title] include Aws::Structure end |
#id ⇒ String
The unique identifier of the context to update.
7681 7682 7683 7684 7685 7686 7687 7688 7689 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 7681 class UpdateAgentContextRequest < Struct.new( :client_token, :profile_arn, :id, :title, :content) SENSITIVE = [:title] include Aws::Structure end |
#profile_arn ⇒ String
The Amazon Resource Name (ARN) of the profile containing the context.
7681 7682 7683 7684 7685 7686 7687 7688 7689 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 7681 class UpdateAgentContextRequest < Struct.new( :client_token, :profile_arn, :id, :title, :content) SENSITIVE = [:title] include Aws::Structure end |
#title ⇒ String
The updated title of the context.
7681 7682 7683 7684 7685 7686 7687 7688 7689 |
# File 'lib/aws-sdk-wellarchitected/types.rb', line 7681 class UpdateAgentContextRequest < Struct.new( :client_token, :profile_arn, :id, :title, :content) SENSITIVE = [:title] include Aws::Structure end |